<?php

require_once get_template_directory() . '/includes/loader.php';

add_action( 'after_setup_theme', 'vicodin_setup_theme' );
add_action( 'after_setup_theme', 'vicodin_load_default_hooks' );


function vicodin_setup_theme() {

	load_theme_textdomain( 'vicodin', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-header' );
	add_theme_support( 'custom-background' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-lightbox' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'editor-styles' );
	add_theme_support( 'post', 'page-attributes' );
    add_theme_support( 'post-formats', array('video', 'gallery', 'audio', 'chat', 'quote', 'aside') );
    
	// Set the default content width.
	$GLOBALS['content_width'] = 525;
	
	/*---------- Register image sizes ----------*/
	
	//Register image sizes
	add_image_size( 'vicodin_600x701', 600, 701, true ); //vicodin_600x701 Feature Product V2
	add_image_size( 'vicodin_600x600', 600, 600, true ); //vicodin_600x600 Latest Product 
	add_image_size( 'vicodin_800x562', 800, 562, true ); //vicodin_800x562 Latest News
	add_image_size( 'vicodin_200x200', 200, 200, true ); //vicodin_200x200 Our Testimonials
	add_image_size( 'vicodin_600x600', 600, 600, true ); //vicodin_600x600 Our Team
	add_image_size( 'vicodin_685x800', 685, 800, true ); //vicodin_685x800 Our Project
	add_image_size( 'vicodin_1170x440', 1170, 440, true ); //vicodin_1170x440 Blog Classic
	add_image_size( 'vicodin_140x140', 140, 140, true ); //vicodin_140x140 Our Team Widget
	add_image_size( 'vicodin_350x350', 350, 350, true ); //vicodin_350x350 Our Team
	/*---------- Register image sizes ends ----------*/
	
	
	
	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'main_menu' => esc_html__( 'Main Menu', 'vicodin' ),
		'user_list_menu' => esc_html__( 'User List Menu', 'vicodin' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'      => 250,
		'height'     => 250,
		'flex-width' => true,
	) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, and column width.
 	 */
	add_editor_style();
	add_action( 'admin_init', 'vicodin_admin_init', 2000000 );
}

/**
 * [vicodin_admin_init]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */


function vicodin_admin_init() {
	remove_action( 'admin_notices', array( 'ReduxFramework', '_admin_notices' ), 99 );
}

/*---------- Sidebar settings ----------*/

/**
 * [vicodin_widgets_init]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */
function vicodin_widgets_init() {

	global $wp_registered_sidebars;

	$theme_options = get_theme_mod( 'vicodin' . '_options-mods' );

	register_sidebar( array(
		'name'          => esc_html__( 'Default Sidebar', 'vicodin' ),
		'id'            => 'default-sidebar',
		'description'   => esc_html__( 'Widgets in this area will be shown on the right-hand side.', 'vicodin' ),
		'before_widget' => '<div id="%1$s" class="widget sidebar-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="widget-title"><h3>',
		'after_title'   => '</h3></div>',
	) );
	register_sidebar(array(
		'name' => esc_html__('Footer Widget', 'vicodin'),
		'id' => 'footer-sidebar',
		'description' => esc_html__('Widgets in this area will be shown in Footer Area.', 'vicodin'),
		'before_widget'=>'<div class="col-xl-4 col-md-6 col-sm-12 col-12"><div id="%1$s" class="footer-widget %2$s">',
		'after_widget'=>'</div></div>',
		'before_title' => '<h4 class="footer-title">',
		'after_title' => '</h4>'
	));
	register_sidebar(array(
		'name' => esc_html__('Footer Widget Two', 'vicodin'),
		'id' => 'footer-sidebar2',
		'description' => esc_html__('Widgets in this area will be shown in Footer Area.', 'vicodin'),
		'before_widget'=>'<div class="col-lg-4 col-md-6 col-sm-12 footer-column"><div id="%1$s" class="footer-widget %2$s">',
		'after_widget'=>'</div></div>',
		'before_title' => '<div class="widget-title"><h3>',
		'after_title' => '</h3></div>'
	));
	if ( class_exists( '\Elementor\Plugin' )){
	register_sidebar(array(
		'name' => esc_html__('Services Widget', 'vicodin'),
		'id' => 'service-sidebar',
		'description' => esc_html__('Widgets in this area will be shown in Services Area.', 'vicodin'),
		'before_widget'=>'<div id="%1$s" class="service-widget sidebar-widget %2$s">',
		'after_widget'=>'</div>',
		'before_title' => '<h4 class="ltn__widget-title">',
		'after_title' => '</h4>'
	));
	register_sidebar(array(
		'name' => esc_html__('Shop Widget', 'vicodin'),
		'id' => 'shop-sidebar',
		'description' => esc_html__('Widgets in this area will be shown in Shop Area.', 'vicodin'),
		'before_widget'=>'<div id="%1$s" class="widget  shop-widget sidebar-widget %2$s">',
		'after_widget'=>'</div>',
		'before_title' => '<h4 class="ltn__widget-title ltn__widget-title-border">',
		'after_title' => '</h4>'
	));
	register_sidebar(array(
	  'name' => esc_html__( 'Blog Listing', 'vicodin' ),
	  'id' => 'blog-sidebar',
	  'description' => esc_html__( 'Widgets in this area will be shown on the right-hand side.', 'vicodin' ),
	  'before_widget'=>'<div id="%1$s" class="widget %2$s">',
	  'after_widget'=>'</div>',
	  'before_title' => '<h4 class="ltn__widget-title ltn__widget-title-border-2">',
	  'after_title' => '</h4>'
	));
	}
	if ( ! is_object( vicodin_WSH() ) ) {
		return;
	}

	$sidebars = vicodin_set( $theme_options, 'custom_sidebar_name' );

	foreach ( array_filter( (array) $sidebars ) as $sidebar ) {

		if ( vicodin_set( $sidebar, 'topcopy' ) ) {
			continue;
		}

		$name = $sidebar;
		if ( ! $name ) {
			continue;
		}
		$slug = str_replace( ' ', '_', $name );

		register_sidebar( array(
			'name'          => $name,
			'id'            => sanitize_title( $slug ),
			'before_widget' => '<div id="%1$s" class="%2$s widget sidebar-widget">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="widget-title"><h3>',
			'after_title'   => '</h3></div>',
		) );
	}

	update_option( 'wp_registered_sidebars', $wp_registered_sidebars );
}

add_action( 'widgets_init', 'vicodin_widgets_init' );

/*---------- Sidebar settings ends ----------*/

/*---------- Gutenberg settings ----------*/

function vicodin_gutenberg_editor_palette_styles() {
    add_theme_support( 'editor-color-palette', array(
        array(
            'name' => esc_html__( 'strong yellow', 'vicodin' ),
            'slug' => 'strong-yellow',
            'color' => '#f7bd00',
        ),
        array(
            'name' => esc_html__( 'strong white', 'vicodin' ),
            'slug' => 'strong-white',
            'color' => '#fff',
        ),
		array(
            'name' => esc_html__( 'light black', 'vicodin' ),
            'slug' => 'light-black',
            'color' => '#242424',
        ),
        array(
            'name' => esc_html__( 'very light gray', 'vicodin' ),
            'slug' => 'very-light-gray',
            'color' => '#797979',
        ),
        array(
            'name' => esc_html__( 'very dark black', 'vicodin' ),
            'slug' => 'very-dark-black',
            'color' => '#000000',
        ),
    ) );
	
	add_theme_support( 'editor-font-sizes', array(
		array(
			'name' => esc_html__( 'Small', 'vicodin' ),
			'size' => 10,
			'slug' => 'small'
		),
		array(
			'name' => esc_html__( 'Normal', 'vicodin' ),
			'size' => 15,
			'slug' => 'normal'
		),
		array(
			'name' => esc_html__( 'Large', 'vicodin' ),
			'size' => 24,
			'slug' => 'large'
		),
		array(
			'name' => esc_html__( 'Huge', 'vicodin' ),
			'size' => 36,
			'slug' => 'huge'
		)
	) );
	
}
add_action( 'after_setup_theme', 'vicodin_gutenberg_editor_palette_styles' );

/*---------- Gutenberg settings ends ----------*/

/*---------- Enqueue Styles and Scripts ----------*/

function vicodin_enqueue_scripts() {
	$options = vicodin_WSH()->option();
	
    //styles
    wp_enqueue_style( 'font-icons', get_template_directory_uri() . '/assets/css/font-icons.css' );
	wp_enqueue_style( 'plugins', get_template_directory_uri() . '/assets/css/plugins.css' );
	wp_enqueue_style( 'vicodin-main', get_stylesheet_uri() );
	wp_enqueue_style( 'vicodin-main-style', get_template_directory_uri() . '/assets/css/style.css' );
	wp_enqueue_style( 'vicodin-main-style-02', get_template_directory_uri() . '/assets/css/style-02.css' );
	wp_enqueue_style( 'vicodin-custom', get_template_directory_uri() . '/assets/css/custom.css' );
	wp_enqueue_style( 'vicodin-responsive', get_template_directory_uri() . '/assets/css/responsive.css' );
	wp_enqueue_style( 'vicodin-woocommerce', get_template_directory_uri() . '/assets/css/woocommerce.css' );
    
	
	//scripts
	wp_enqueue_script( 'jquery-ui-core');
	wp_enqueue_script( 'vicodin-plugins', get_template_directory_uri().'/assets/js/plugins.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'contact', get_template_directory_uri().'/assets/js/contact.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'vicodin-main', get_template_directory_uri().'/assets/js/main.js', array(), false, true );
	if( is_singular() ) wp_enqueue_script('comment-reply');
}
add_action( 'wp_enqueue_scripts', 'vicodin_enqueue_scripts' );

/*---------- Enqueue styles and scripts ends ----------*/

/*---------- Google fonts ----------*/

function vicodin_fonts_url() {
	
	$fonts_url = '';
	
		
		$font_families['Open+Sans']      = 'Open Sans:wght@0,400,600,700&display=swap';
		$font_families['Rajdhani']      = 'Rajdhani:wght@0,400,500,600,700&display=swap';
		$font_families['Nunito+Sans']      = 'Nunito+Sans:wght@0,300,400,600,700&display=swap';
		$font_families['Titillium+Web']      = 'Titillium Web:wght@0,400,600,700,900&display=swap';
		$font_families['Poppins']      = 'Poppins:wght@0,400,500,600,700,800,900&display=swap';
		$font_families['Josefin+Sans']      = 'Josefin Sans:wght@0,400,500,600,700&display=swap';
		$font_families['Nunito']      = 'Nunito:wght@0,400,600,700&display=swap';

		$font_families = apply_filters( 'VICODIN/includes/classes/header_enqueue/font_families', $font_families );

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);

		$protocol  = is_ssl() ? 'https' : 'http';
		$fonts_url = add_query_arg( $query_args, $protocol . '://fonts.googleapis.com/css' );

		return esc_url_raw($fonts_url);

}

function vicodin_theme_styles() {
    wp_enqueue_style( 'vicodin-theme-fonts', vicodin_fonts_url(), array(), null );
}

add_action( 'wp_enqueue_scripts', 'vicodin_theme_styles' );
add_action( 'admin_enqueue_scripts', 'vicodin_theme_styles' );

/*---------- Google fonts ends ----------*/

/*---------- More functions ----------*/

// 1) vicodin_set function

/**
 * [vicodin_set description]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */
if ( ! function_exists( 'vicodin_set' ) ) {
	function vicodin_set( $var, $key, $def = '' ) {

		if ( is_object( $var ) && isset( $var->$key ) ) {
			return $var->$key;
		} elseif ( is_array( $var ) && isset( $var[ $key ] ) ) {
			return $var[ $key ];
		} elseif ( $def ) {
			return $def;
		} else {
			return false;
		}
	}
}

// 2) vicodin_add_editor_styles function

function vicodin_add_editor_styles() {
    add_editor_style( 'editor-style.css' );
}
add_action( 'admin_init', 'vicodin_add_editor_styles' );

// 3) Add specific CSS class by filter body class.

$options = vicodin_WSH()->option(); 
if( vicodin_set($options, 'boxed_wrapper') ){

add_filter( 'body_class', function( $classes ) {
    $classes[] = 'boxed_wrapper';
    return $classes;
} );
}

//Related Products

function acrepair_related_products_limit() {
  global $product;
	
	$args['posts_per_page'] = 6;
	return $args;
}
add_filter( 'woocommerce_output_related_products_args', 'acrepair_related_products_args', 20 );
  function acrepair_related_products_args( $args ) {
	$args['posts_per_page'] = 3; // 4 related products
	$args['columns'] = 1; // arranged in 2 columns
	return $args;
}
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328032&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        