<?php namespace VICODINPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class About_Us extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'vicodin_about_us';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'About Us', 'vicodin' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-library-open';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'vicodin' ];
    }

    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'about_us',
            [
                'label' => esc_html__( 'About Us', 'vicodin' ),
            ]
        );
		$this->add_control(
			'about_image',
			[
				'label' => __( 'About Image', 'vicodin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'vicodin' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Text', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Text', 'vicodin' ),
			]
		);
		$this->add_control(
			'features_list',
			[
				'label'       => __( 'Features List', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your features list', 'vicodin' ),
			]
		);
		$this->add_control(
			'author_image',
			[
				'label' => __( 'Author Image', 'vicodin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'author_title',
			[
				'label'       => __( 'Author Title', 'vicodin' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your author title', 'vicodin' ),
			]
		);
		$this->add_control(
			'author_subtitle',
			[
				'label'       => __( 'Author Subtitle', 'vicodin' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your author subtitle', 'vicodin' ),
			]
		);
		$this->add_control(
			'phone_title',
			[
				'label'       => __( 'Phone Title', 'vicodin' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your phone title', 'vicodin' ),
			]
		);
		$this->add_control(
			'phone_no',
			[
				'label'       => __( 'Phone Number', 'vicodin' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your phone number', 'vicodin' ),
			]
		);
		$this->end_controls_section();
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
        ?>
		
        
        <!-- ABOUT US AREA START -->
    <div class="ltn__about-us-area pt-25 pb-120 ">
        <div class="container">
            <div class="row">
                <div class="col-lg-6 align-self-center">
                    <?php if($settings['about_image']['id']){ ?>
                    <div class="about-us-img-wrap about-img-left">
                        <img src="<?php echo esc_url(wp_get_attachment_url($settings['about_image']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'vicodin'); ?>">
                    </div>
                    <?php } ?>
                </div>
                <div class="col-lg-6 align-self-center">
                    <div class="about-us-info-wrap">
                        <?php if($settings['title'] || $settings['text']) { ?>
                        <div class="section-title-area ltn__section-title-2--- mb-30">
                             <?php if($settings['title']) { ?><h1 class="section-title"><?php echo wp_kses($settings['title'], true);?></h1><?php } ?>
                             <?php if($settings['text']) { ?><p><?php echo wp_kses($settings['text'], true);?></p><?php } ?>
                        </div>
                        <?php } ?>
                        <?php $features_list = $settings['features_list'];
							if(!empty($features_list)){
							$features_list = explode("\n", ($features_list)); 
						?>
						<ul class="ltn__list-item-1 ltn__list-item-1-before--- clearfix">
							<?php foreach($features_list as $features): ?>
								<li><i class="fas fa-check-square"></i> <?php echo wp_kses($features, true); ?></li>
							 <?php endforeach; ?>
						</ul>
						<?php } ?>
                        <div class="about-author-info-2 border-top mt-30 pt-20">
                            <ul>
                                <?php if($settings['author_image']['id'] || $settings['author_title'] || $settings['author_subtitle']){ ?>
                                <li>
                                	<div class="about-author-info-2-brief  d-flex">
                                        <?php if($settings['author_image']['id']){ ?>
                                        <div class="author-img">
                                        <img src="<?php echo esc_url(wp_get_attachment_url($settings['author_image']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'vicodin'); ?>">
                                        </div>
                                        <?php } ?>
                                        <div class="author-name-designation">
                                            <?php if($settings['author_title']) { ?><h4 class="mb-0"><?php echo wp_kses($settings['author_title'], true);?></h4><?php } ?>
                                            <?php if($settings['author_subtitle']) { ?><small><?php echo wp_kses($settings['author_subtitle'], true);?></small><?php } ?>
                                        </div>
                                    </div>
                                   
                                </li>
                                <?php } ?> 
                               <?php if($settings['phone_title'] || $settings['phone_no']) { ?>
                                <li>
                                    <div class="about-author-info-2-contact  d-flex">
                                        <div class="about-contact-icon d-flex align-self-center mr-10">
                                            <i class="icon-call"></i>
                                        </div>
                                        <div class="about-author-info-2-contact-info">
                                            <?php if($settings['phone_title']) { ?><small><?php echo wp_kses($settings['phone_title'], true);?></small> <?php } ?>
                                            <?php if($settings['phone_no']) { ?><h6 class="mb-0"><?php echo wp_kses($settings['phone_no'], true);?></h6> <?php } ?>
                                        </div>
                                    </div>
                                </li>
                                 <?php } ?> 
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- ABOUT US AREA END -->
     
        
        
        <?php
    }
}
