<?php namespace VICODINPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Call_To_Action_V2 extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'vicodin_call_to_action_v2';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Call To Action V2', 'vicodin' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-library-open';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'vicodin' ];
    }

    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'call_to_action_v2',
            [
                'label' => esc_html__( 'Call To Action V2', 'vicodin' ),
            ]
        );
		$this->add_control(
			'bg_image',
			[
				'label' => __( 'Background Image', 'vicodin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'vicodin' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub Title', 'vicodin' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'vicodin' ),
			]
		);
		$this->add_control(
			'btn_title',
			[
				'label'       => __( 'Button Title', 'vicodin' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title', 'vicodin' ),
				'default'     => __( 'Read More', 'vicodin' ),
			]
		);
		$this->add_control(
			'btn_link',
				[
				  'label' => __( 'Button Url', 'vicodin' ),
				  'type' => Controls_Manager::URL,
				  'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
				  'show_external' => true,
				  'default' => [
				    'url' => '',
				    'is_external' => true,
				    'nofollow' => true,
				  ],
			 ]
		);
		$this->add_control(
			'btn_title1',
			[
				'label'       => __( 'Button Title 1', 'vicodin' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title', 'vicodin' ),
				'default'     => __( 'Read More', 'vicodin' ),
			]
		);
		$this->add_control(
			'btn_link1',
				[
				  'label' => __( 'Button Url 1', 'vicodin' ),
				  'type' => Controls_Manager::URL,
				  'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
				  'show_external' => true,
				  'default' => [
				    'url' => '',
				    'is_external' => true,
				    'nofollow' => true,
				  ],
			 ]
		);
		$this->add_control(
			'feature_image',
			[
				'label' => __( 'Feature Image', 'vicodin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'feature_image1',
			[
				'label' => __( 'Feature Image 1', 'vicodin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->end_controls_section();
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
        ?>
		
        <!-- CALL TO ACTION START (call-to-action-4) -->
        <div class="ltn__call-to-action-area ltn__call-to-action-4 bg-image pt-115 pb-120" <?php if($settings['bg_image']['id']){ ?> data-bs-bg="<?php echo esc_url(wp_get_attachment_url($settings['bg_image']['id'])); ?>" <?php } ?>>
            <div class="container">
                <div class="row">
                    <div class="col-lg-12">
                        <div class="call-to-action-inner call-to-action-inner-4 text-center">
                            <?php if($settings['title'] || $settings['subtitle']) { ?>
                            <div class="section-title-area ltn__section-title-2">
                                <?php if($settings['subtitle']) { ?><h6 class="section-subtitle ltn__secondary-color"><?php echo wp_kses($settings['subtitle'], true);?></h6><?php } ?>
                                <?php if($settings['title']) { ?><h1 class="section-title white-color"><?php echo wp_kses($settings['title'], true);?></h1><?php } ?>
                            </div>
                            <?php } ?>
                            <div class="btn-wrapper">
                               <?php if($settings['btn_link']['url'] and $settings['btn_title']) { ?>
                               	<a href="<?php echo esc_url($settings['btn_link']['url']);?>" class="theme-btn-1 btn btn-effect-1"><?php echo wp_kses($settings['btn_title'], true);?></a>
                                <?php } ?>
                                <?php if($settings['btn_link1']['url'] and $settings['btn_title1']) { ?>
                                <a href="<?php echo esc_url($settings['btn_link1']['url']);?>" class="btn btn-transparent btn-effect-3 white-color"><?php echo wp_kses($settings['btn_title1'], true);?></a>
                           		 <?php } ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <?php if($settings['feature_image']['id']){ ?>
            <div class="ltn__call-to-4-img-1">
                <img src="<?php echo esc_url(wp_get_attachment_url($settings['feature_image']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'vicodin'); ?>">
            </div>
            <?php } ?>
            <?php if($settings['feature_image1']['id']){ ?>
            <div class="ltn__call-to-4-img-2">
                <img src="<?php echo esc_url(wp_get_attachment_url($settings['feature_image1']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'vicodin'); ?>">
            </div>
            <?php } ?>
        </div>
        <!-- CALL TO ACTION END -->
      
      
        
             
        <?php
    }
}
