<?php namespace VICODINPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Campaign_Ticket extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'vicodin_campaign_ticket';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Campaign Ticket', 'vicodin' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-library-open';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'vicodin' ];
    }

    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'campaign_ticket',
            [
                'label' => esc_html__( 'Campaign Ticket', 'vicodin' ),
            ]
        );
		$this->add_control(
			'style_two',
			[
				'label'   => esc_html__( 'Choose Different Style', 'vicodin' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'one',
				'options' => array(
					'one' => esc_html__( 'Choose Style V1', 'vicodin' ),
					'two' => esc_html__( 'Choose Style V2 ', 'vicodin' ),
				),
			]
		);
		$this->add_control(
			'bg_image',
			[
				'label' => __( 'Background Image', 'vicodin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'vicodin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'vicodin' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'vicodin' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Text', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Text', 'vicodin' ),
			]
		);
		$this->add_control(
			'countdown',
			[
				'label'       => __( 'Countdown', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your countdown', 'vicodin' ),
			]
		);
		$this->add_control(
			'btn_title',
			[
				'label'       => __( 'Button Title', 'vicodin' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'vicodin' ),
			]
		);
		$this->add_control(
			'btn_link',
				[
				  'label' => __( 'Button Url', 'vicodin' ),
				  'type' => Controls_Manager::URL,
				  'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
				  'show_external' => true,
				  'default' => [
				    'url' => '',
				    'is_external' => true,
				    'nofollow' => true,
				  ],
			 ]
		);
		$this->add_control(
			'btn_title_1',
			[
				'label'       => __( 'Button Title 1', 'vicodin' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'vicodin' ),
			]
		);
		$this->add_control(
			'btn_link_1',
				[
				  'label' => __( 'Button Url 1', 'vicodin' ),
				  'type' => Controls_Manager::URL,
				  'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
				  'show_external' => true,
				  'default' => [
				    'url' => '',
				    'is_external' => true,
				    'nofollow' => true,
				  ],
			 ]
		);
		$this->end_controls_section();
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
        ?>
		
    <?php if($settings['style_two'] == 'two'): ?>    
     <!-- COUNTDOWN AREA START -->
    <div class="ltn__call-to-action-area section-bg-1 bg-image pt-120 pb-120" <?php if($settings['bg_image']['id']){ ?> data-bs-bg="<?php echo esc_url(wp_get_attachment_url($settings['bg_image']['id'])); ?>"<?php } ?>>
        <div class="container">
            <div class="row">
                <div class="col-lg-7 col-md-6 col-sm-4">
                    <!-- <img src="img/banner/15.png" alt="#"> -->
                </div>
                <div class="col-lg-5 col-md-6 col-sm-8">
                    <div class="call-to-action-inner text-color-white--- text-center---">
                        <div class="section-title-area ltn__section-title-2--- text-center---">
                            <?php if($settings['subtitle']) { ?><h6 class="ltn__secondary-color"><?php echo wp_kses($settings['subtitle'], true);?></h6><?php } ?>
                            <?php if($settings['title']) { ?><h1 class="section-title"><?php echo wp_kses($settings['title'], true);?></h1><?php } ?>
                            <?php if($settings['text']) { ?><p><?php echo wp_kses($settings['text'], true);?></p><?php } ?>
                        </div>
                        <div class="ltn__countdown ltn__countdown-3 bg-white--" data-countdown="<?php echo esc_attr($settings['countdown']);?>"></div>
                       	<?php if($settings['btn_link']['url'] and $settings['btn_title'] || $settings['btn_link_1']['url'] and $settings['btn_title_1']){ ?>
                        <div class="btn-wrapper animated">
                            <?php if($settings['btn_link']['url'] and $settings['btn_title']){ ?><a href="<?php echo esc_url($settings['btn_link']['url']); ?>" class="theme-btn-1 btn btn-effect-1 text-uppercase"><?php echo wp_kses($settings['btn_title'], true);?></a><?php } ?>
                            <?php if($settings['btn_link_1']['url'] and $settings['btn_title_1']){ ?><a href="<?php echo esc_url($settings['btn_link_1']['url']); ?>" class="ltn__secondary-color text-decoration-underline"><?php echo wp_kses($settings['btn_title_1'], true);?></a><?php } ?>
                        </div>
                        <?php } ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- COUNTDOWN AREA END -->
   
   
    <?php else: ?>
    
         
    <!-- COUNTDOWN AREA START -->
    <div class="ltn__call-to-action-area section-bg-1 bg-image pt-120 pb-120" <?php if($settings['bg_image']['id']){ ?> data-bs-bg="<?php echo esc_url(wp_get_attachment_url($settings['bg_image']['id'])); ?>"<?php } ?>>
        <div class="container">
            <div class="row">
                <div class="col-lg-7">
                    <div class="call-to-action-inner text-color-white--- text-center---">
                        <div class="section-title-area ltn__section-title-2--- text-center---">
                             <?php if($settings['subtitle']) { ?><h6 class="ltn__secondary-color"><?php echo wp_kses($settings['subtitle'], true);?></h6> <?php } ?>
                             <?php if($settings['title']) { ?><h1 class="section-title"><?php echo wp_kses($settings['title'], true);?></h1> <?php } ?>
                             <?php if($settings['text']) { ?><p><?php echo wp_kses($settings['text'], true);?></p> <?php } ?>
                        </div>
                        <div class="ltn__countdown ltn__countdown-3 bg-white--" data-countdown="<?php echo esc_attr($settings['countdown']);?>"></div>
                       	<?php if($settings['btn_link']['url'] and $settings['btn_title'] || $settings['btn_link_1']['url'] and $settings['btn_title_1']){ ?>
                        <div class="btn-wrapper animated">
                            <?php if($settings['btn_link']['url'] and $settings['btn_title']){ ?><a href="<?php echo esc_url($settings['btn_link']['url']); ?>" class="theme-btn-1 btn btn-effect-1 text-uppercase"><?php echo wp_kses($settings['btn_title'], true);?></a><?php } ?>
                            <?php if($settings['btn_link_1']['url'] and $settings['btn_title_1']){ ?><a href="<?php echo esc_url($settings['btn_link_1']['url']); ?>" class="ltn__secondary-color text-decoration-underline"><?php echo wp_kses($settings['btn_title_1'], true);?></a><?php } ?>
                        </div>
                       <?php } ?> 
                    </div>
                </div>
                <div class="col-lg-5">
                    <!-- <img src="img/banner/15.png" alt="#"> -->
                </div>
            </div>
        </div>
    </div>
    <!-- COUNTDOWN AREA END -->
        
   
                 
        <?php endif;
    }
}
