<?php namespace VICODINPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Comming_Soon extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'vicodin_comming_soon';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Comming Soon', 'vicodin' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-library-open';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'vicodin' ];
    }

    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'comming_soon',
            [
                'label' => esc_html__( 'Comming Soon', 'vicodin' ),
            ]
        );
		$this->add_control(
			'bg_image',
			[
				'label' => __( 'Background Image', 'vicodin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'vicodin' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub Title', 'vicodin' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'vicodin' ),
			]
		);
		$this->add_control(
			'our_date',
			[
				'label'       => __( 'Date', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Date', 'vicodin' ),
			]
		);
		$this->add_control(
			'countdown',
			[
				'label'       => __( 'Countdown', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Countdown', 'vicodin' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Text', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Text', 'vicodin' ),
			]
		);
		$this->add_control(
			'newsletter_form_url',
			[
				'label'       => __( 'Newsletter Form Url', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your newsletter form url', 'vicodin' ),
			]
		);
		$this->add_control(
			'btn_title',
			[
				'label'       => __( 'Button Title', 'vicodin' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'vicodin' ),
			]
		);
		$this->add_control(
			'btn_link',
				[
				  'label' => __( 'Button Url', 'vicodin' ),
				  'type' => Controls_Manager::URL,
				  'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
				  'show_external' => true,
				  'default' => [
				    'url' => '',
				    'is_external' => true,
				    'nofollow' => true,
				  ],
			 ]
		);
		$this->end_controls_section();
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
        ?>
		
        
       
        <!-- 404 area start -->
    <div class="ltn__coming-soon-area section-bg-2 text-color-white bg-overlay-theme-black-90 bg-image" <?php if($settings['bg_image']['id']){ ?> data-bs-bg="<?php echo esc_url(wp_get_attachment_url($settings['bg_image']['id'])); ?>"<?php } ?>>
        <div class="container">
            <div class="row">
                <div class="col-lg-12">
                    <div class="coming-soon-inner">
                        <?php if($settings['subtitle'] || $settings['title'] || $settings['our_date']) { ?>
                        <div class="section-title-area ltn__section-title-2">
                            <?php if($settings['subtitle']) { ?><h6 class="section-subtitle ltn__secondary-color"><?php echo wp_kses($settings['subtitle'], true);?></h6><?php } ?>
                            <?php if($settings['title']) { ?><h1 class="section-title white-color"><?php echo wp_kses($settings['title'], true);?></h1><?php } ?>
                            <?php if($settings['our_date']) { ?><h5 class="ltn__secondary-color"><?php echo wp_kses($settings['our_date'], true);?></h5><?php } ?>
                        </div>
                        <?php } ?>
                        <?php if($settings['countdown']) { ?>
                        <div class="ltn__countdown mb-20" data-countdown="<?php echo wp_kses($settings['countdown'], true);?>"></div>
						<?php } ?>
                        <div class="ltn__newsletter-inner mt-50">
                            <?php if($settings['text']) { ?><h3><?php echo wp_kses($settings['text'], true);?></h3><?php } ?>
                             <?php if($settings['newsletter_form_url']) { ?>
							<?php echo do_shortcode($settings['newsletter_form_url']);?>
                            <?php } ?>
                        </div>
                         <?php if($settings['btn_link']['url'] and $settings['btn_title']){ ?>
                        <div class="btn-wrapper mt-50">
                            <a href="<?php echo esc_url($settings['btn_link']['url']); ?>" class="btn theme-btn-2 btn-effect-2 text-uppercase"><?php echo wp_kses($settings['btn_title'], true);?></a>
                        </div>
                        <?php } ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- 404 area end -->

     
     
        
        
        <?php
    }
}
