<?php namespace VICODINPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Contact_Info extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'vicodin_contact_info';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Contact Info', 'vicodin' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-library-open';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'vicodin' ];
    }

    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'contact_info',
            [
                'label' => esc_html__( 'Contact Info', 'vicodin' ),
            ]
        );
		
		$this->add_control(
              'info', 
			  	[
            		'type' => Controls_Manager::REPEATER,
            		'separator' => 'before',
            		'default' => 
						[
                			['block_title' => esc_html__('Boston, New York', 'vicodin')],
							['block_title' => esc_html__('Boston, New York', 'vicodin')],
							['block_title' => esc_html__('Boston, New York', 'vicodin')],
            			],
            		'fields' => 
						[
							[
                    			'name' => 'block_title',
                    			'label' => esc_html__('Title', 'vicodin'),
								'label_block' => true,
                    			'type' => Controls_Manager::TEXT,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'address',
                    			'label' => esc_html__('Address', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'phone_no',
                    			'label' => esc_html__('Phone Number', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'btn_title',
                    			'label' => esc_html__('Button Title', 'vicodin'),
								'label_block' => true,
                    			'type' => Controls_Manager::TEXT,
                    			'default' => esc_html__('Read More', 'vicodin')
                			],
							[
                    			'name' => 'btn_link',
								'label' => __( 'Button Link', 'vicodin' ),
							    'type' => Controls_Manager::URL,
							    'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
							    'show_external' => true,
							    'default' => ['url' => '','is_external' => true,'nofollow' => true,],
                			],
							[
                    			'name' => 'btn_title1',
                    			'label' => esc_html__('Button Title 1', 'vicodin'),
								'label_block' => true,
                    			'type' => Controls_Manager::TEXT,
                    			'default' => esc_html__('Read More', 'vicodin')
                			],
							[
                    			'name' => 'btn_link1',
								'label' => __( 'Button Link 1', 'vicodin' ),
							    'type' => Controls_Manager::URL,
							    'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
							    'show_external' => true,
							    'default' => ['url' => '','is_external' => true,'nofollow' => true,],
                			],
						],
            	    'title_field' => '{{block_title}}',
                 ]
        );
		$this->add_control(
			'title_1',
			[
				'label'       => __( 'Title 1', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title 1', 'vicodin' ),
			]
		);
		$this->add_control(
              'info_1', 
			  	[
            		'type' => Controls_Manager::REPEATER,
            		'separator' => 'before',
            		'default' => 
						[
                			['block_title' => esc_html__('Boston, New York', 'vicodin')],
							['block_title' => esc_html__('Boston, New York', 'vicodin')],
							['block_title' => esc_html__('Boston, New York', 'vicodin')],
            			],
            		'fields' => 
						[
							[
                    			'name' => 'block_title',
                    			'label' => esc_html__('Title', 'vicodin'),
								'label_block' => true,
                    			'type' => Controls_Manager::TEXT,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'address',
                    			'label' => esc_html__('Address', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'phone_no',
                    			'label' => esc_html__('Phone Number', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'btn_title',
                    			'label' => esc_html__('Button Title', 'vicodin'),
								'label_block' => true,
                    			'type' => Controls_Manager::TEXT,
                    			'default' => esc_html__('Read More', 'vicodin')
                			],
							[
                    			'name' => 'btn_link',
								'label' => __( 'Button Link', 'vicodin' ),
							    'type' => Controls_Manager::URL,
							    'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
							    'show_external' => true,
							    'default' => ['url' => '','is_external' => true,'nofollow' => true,],
                			],
							[
                    			'name' => 'btn_title1',
                    			'label' => esc_html__('Button Title 1', 'vicodin'),
								'label_block' => true,
                    			'type' => Controls_Manager::TEXT,
                    			'default' => esc_html__('Read More', 'vicodin')
                			],
							[
                    			'name' => 'btn_link1',
								'label' => __( 'Button Link 1', 'vicodin' ),
							    'type' => Controls_Manager::URL,
							    'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
							    'show_external' => true,
							    'default' => ['url' => '','is_external' => true,'nofollow' => true,],
                			],
						],
            	    'title_field' => '{{block_title}}',
                 ]
        );
		$this->add_control(
			'title_2',
			[
				'label'       => __( 'Title 2', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title 2', 'vicodin' ),
			]
		);
		$this->add_control(
              'info_2', 
			  	[
            		'type' => Controls_Manager::REPEATER,
            		'separator' => 'before',
            		'default' => 
						[
                			['block_title' => esc_html__('Boston, New York', 'vicodin')],
							['block_title' => esc_html__('Boston, New York', 'vicodin')],
							['block_title' => esc_html__('Boston, New York', 'vicodin')],
            			],
            		'fields' => 
						[
							[
                    			'name' => 'block_title',
                    			'label' => esc_html__('Title', 'vicodin'),
								'label_block' => true,
                    			'type' => Controls_Manager::TEXT,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'address',
                    			'label' => esc_html__('Address', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'phone_no',
                    			'label' => esc_html__('Phone Number', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'btn_title',
                    			'label' => esc_html__('Button Title', 'vicodin'),
								'label_block' => true,
                    			'type' => Controls_Manager::TEXT,
                    			'default' => esc_html__('Read More', 'vicodin')
                			],
							[
                    			'name' => 'btn_link',
								'label' => __( 'Button Link', 'vicodin' ),
							    'type' => Controls_Manager::URL,
							    'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
							    'show_external' => true,
							    'default' => ['url' => '','is_external' => true,'nofollow' => true,],
                			],
							[
                    			'name' => 'btn_title1',
                    			'label' => esc_html__('Button Title 1', 'vicodin'),
								'label_block' => true,
                    			'type' => Controls_Manager::TEXT,
                    			'default' => esc_html__('Read More', 'vicodin')
                			],
							[
                    			'name' => 'btn_link1',
								'label' => __( 'Button Link 1', 'vicodin' ),
							    'type' => Controls_Manager::URL,
							    'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
							    'show_external' => true,
							    'default' => ['url' => '','is_external' => true,'nofollow' => true,],
                			],
						],
            	    'title_field' => '{{block_title}}',
                 ]
        );
		$this->end_controls_section();
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
        ?>
		
      

    <!-- GOOGLE MAP LOCATIONS LIST AREA START -->
    <div class="ltn__google-map-locations-list-area mt-115 mb-70">
        <div class="container">
            <div class="row">
                               
                <?php if($settings['title']) { ?>
                <div class="col-lg-12">
                    <div class="ltn__state-location">
                        <h2 class="ltn__state-location-title"><?php echo wp_kses($settings['title'], true);?></h2>
                    </div>
                </div>
                <?php } ?>
                <?php foreach($settings['info'] as $key => $item): ?>
                <div class="col-lg-4">
                    <div class="ltn__map-item">
                        <?php if($item['block_title']) { ?><h3 class="ltn__location-name"><?php echo wp_kses($item['block_title'], true);?></h3><?php } ?>
                        <?php if($item['address']) { ?><h5 class="ltn__location-single-info"><i class="fas fa-map-marked-alt"></i><?php echo wp_kses($item['address'], true);?></h5><?php } ?>
                        <?php if($item['phone_no']) { ?><h4 class="ltn__location-single-info"><i class="fas fa-phone-volume"></i><?php echo wp_kses($item['phone_no'], true);?></h4><?php } ?>
                        <div class="btn-wrapper">
                            <?php if($item['btn_link']['url'] and $item['btn_title']) { ?><a href="<?php echo esc_url($item['btn_link']['url']);?>" class="btn btn-transparent btn-border btn-effect-4"><i class="fas fa-location-arrow"></i> <?php echo wp_kses($item['btn_title'], true);?></a><?php } ?>
                            <?php if($item['btn_link1']['url'] and $item['btn_title1']) { ?><a href="<?php echo esc_url($item['btn_link1']['url']);?>" class="btn btn-transparent btn-border btn-effect-3"><i class="fas fa-globe"></i> <?php echo wp_kses($item['btn_title1'], true);?></a><?php } ?>
                        </div>
                    </div>
                </div>
               	<?php endforeach; ?>
                
                 <?php if($settings['title_1']) { ?>
                <div class="col-lg-12">
                    <div class="ltn__state-location">
                        <h2 class="ltn__state-location-title"><?php echo wp_kses($settings['title_1'], true);?></h2>
                    </div>
                </div>
                <?php } ?>
                <?php foreach($settings['info_1'] as $key => $item): ?>
                <div class="col-lg-4">
                    <div class="ltn__map-item">
                        <?php if($item['block_title']) { ?><h3 class="ltn__location-name"><?php echo wp_kses($item['block_title'], true);?></h3><?php } ?>
                        <?php if($item['address']) { ?><h5 class="ltn__location-single-info"><i class="fas fa-map-marked-alt"></i><?php echo wp_kses($item['address'], true);?></h5><?php } ?>
                        <?php if($item['phone_no']) { ?><h4 class="ltn__location-single-info"><i class="fas fa-phone-volume"></i><?php echo wp_kses($item['phone_no'], true);?></h4><?php } ?>
                        <div class="btn-wrapper">
                            <?php if($item['btn_link']['url'] and $item['btn_title']) { ?><a href="<?php echo esc_url($item['btn_link']['url']);?>" class="btn btn-transparent btn-border btn-effect-4"><i class="fas fa-location-arrow"></i> <?php echo wp_kses($item['btn_title'], true);?></a><?php } ?>
                            <?php if($item['btn_link1']['url'] and $item['btn_title1']) { ?><a href="<?php echo esc_url($item['btn_link1']['url']);?>" class="btn btn-transparent btn-border btn-effect-3"><i class="fas fa-globe"></i> <?php echo wp_kses($item['btn_title1'], true);?></a><?php } ?>
                        </div>
                    </div>
                </div>
               	<?php endforeach; ?>
                
 				<?php if($settings['title_2']) { ?>
                <div class="col-lg-12">
                    <div class="ltn__state-location">
                        <h2 class="ltn__state-location-title"><?php echo wp_kses($settings['title_2'], true);?></h2>
                    </div>
                </div>
                <?php } ?>
                <?php foreach($settings['info_2'] as $key => $item): ?>
                <div class="col-lg-4">
                    <div class="ltn__map-item">
                        <?php if($item['block_title']) { ?><h3 class="ltn__location-name"><?php echo wp_kses($item['block_title'], true);?></h3><?php } ?>
                        <?php if($item['address']) { ?><h5 class="ltn__location-single-info"><i class="fas fa-map-marked-alt"></i><?php echo wp_kses($item['address'], true);?></h5><?php } ?>
                        <?php if($item['phone_no']) { ?><h4 class="ltn__location-single-info"><i class="fas fa-phone-volume"></i><?php echo wp_kses($item['phone_no'], true);?></h4><?php } ?>
                        <div class="btn-wrapper">
                            <?php if($item['btn_link']['url'] and $item['btn_title']) { ?><a href="<?php echo esc_url($item['btn_link']['url']);?>" class="btn btn-transparent btn-border btn-effect-4"><i class="fas fa-location-arrow"></i> <?php echo wp_kses($item['btn_title'], true);?></a><?php } ?>
                            <?php if($item['btn_link1']['url'] and $item['btn_title1']) { ?><a href="<?php echo esc_url($item['btn_link1']['url']);?>" class="btn btn-transparent btn-border btn-effect-3"><i class="fas fa-globe"></i> <?php echo wp_kses($item['btn_title1'], true);?></a><?php } ?>
                        </div>
                    </div>
                </div>
               	<?php endforeach; ?>
            </div>
        </div>
    </div>
    <!-- GOOGLE MAP LOCATIONS LIST AREA END -->
      
     
     
    
   

       
             
        <?php
    }
}
