<?php namespace VICODINPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Core_Feature extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'vicodin_core_feature';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( ' Core Feature', 'vicodin' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-library-open';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'vicodin' ];
    }

    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'core_feature',
            [
                'label' => esc_html__( 'Core Feature', 'vicodin' ),
            ]
        );
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'vicodin' ),
			]
		);
		$this->add_control(
           'features', 
			  	[
            		'type' => Controls_Manager::REPEATER,
            		'separator' => 'before',
            		'default' => 
						[
                			['block_title' => esc_html__('Medicine Cap', 'vicodin')],
                			['block_title' => esc_html__('Dental Item', 'vicodin')],
                			['block_title' => esc_html__('Best Deals', 'vicodin')],
                			['block_title' => esc_html__('All Products', 'vicodin')],
                			['block_title' => esc_html__('Germs Pads', 'vicodin')],
                			['block_title' => esc_html__('Accessories', 'vicodin')],
                			['block_title' => esc_html__('Medicine Cap', 'vicodin')],
                			['block_title' => esc_html__('Dental Item', 'vicodin')],
            			],
            		'fields' => 
						[
                			[
								'name' => 'feature_image',
								'label' => esc_html__('Feature Image', 'vicodin'),
								'type' => Controls_Manager::MEDIA,
								'default' => ['url' => Utils::get_placeholder_image_src(),],
							],
							[
                    			'name' => 'block_title',
                    			'label' => esc_html__('Title', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'block_text',
                    			'label' => esc_html__('Text', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
								  'name' => 'feature_link',
								  'label' => __( 'Feture Url', 'vicodin' ),
								  'type' => Controls_Manager::URL,
								  'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
								  'show_external' => true,
								  'default' => [
									'url' => '',
									'is_external' => true,
									'nofollow' => true,
								  ],
							 ],
						],
            	    'title_field' => '{{block_title}}',
                 ]
        );
		$this->end_controls_section();
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
        ?>
		
       
       <!-- FEATURE AREA START ( Feature - 6) -->
    <div class="ltn__feature-area pt-90 pb-90">
        <div class="container">
            <div class="row">
                <div class="col-lg-12">
                    <?php if($settings['title']){?>
                    <div class="section-title-area ltn__section-title-2--- text-center">
                        <h1 class="section-title"><?php echo wp_kses($settings['title'], true);?></h1>
                    </div>
                    <?php } ?>
                </div>
            </div>
            <div class="row ltn__custom-gutter">
                <?php foreach($settings['features'] as $key => $item): ?>
                <div class="col-lg-3 col-sm-6 col-12">
                    <div class="ltn__feature-item ltn__feature-item-6 text-center">
                        <?php if($item['feature_image']['id']){?>
                        <div class="ltn__feature-icon">
                            <!-- <span><i class="flaticon-apartment"></i></span> -->
                            <img src="<?php echo esc_url(wp_get_attachment_url($item['feature_image']['id']));?>" alt="<?php esc_attr_e('Awesome Image', 'vicodin'); ?>">
                        </div>
                        <?php } ?>
                       <?php if($item['block_title'] || $item['block_text']){?>
                        <div class="ltn__feature-info">
                            <?php if($item['block_title']){?><h4><a href="<?php echo esc_url($item['feature_link']['url']); ?>"><?php echo wp_kses($item['block_title'], true);?></a></h4><?php } ?>
                            <?php if($item['block_text']){?><p><?php echo wp_kses($item['block_text'], true);?></p><?php } ?>
                        </div>
                        <?php } ?>
                    </div>
                </div>
                <?php endforeach; ?>
            </div>
        </div>
    </div>
    <!-- FEATURE AREA END -->
       
       
       
       
       
             
        <?php
    }
}
