<?php namespace VICODINPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Covering_Mask extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'vicodin_covering_mask';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Covering Mask', 'vicodin' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-library-open';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'vicodin' ];
    }

    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'covering_mask',
            [
                'label' => esc_html__( 'Covering Mask', 'vicodin' ),
            ]
        );
		$this->add_control(
			'style_two',
			[
				'label'   => esc_html__( 'Choose Different Style', 'vicodin' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'one',
				'options' => array(
					'one' => esc_html__( 'Choose Style V1', 'vicodin' ),
					'two' => esc_html__( 'Choose Style V2 ', 'vicodin' ),
				),
			]
		);
		$this->add_control(
			'bg_image',
			[
				'label' => __( 'Background Image', 'vicodin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'vicodin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub Title', 'vicodin' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'vicodin' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Text', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Text', 'vicodin' ),
			]
		);
		$this->add_control(
           'features', 
			  	[
            		'type' => Controls_Manager::REPEATER,
            		'separator' => 'before',
            		'default' => 
						[
                			['block_title' => esc_html__('Activated Carbon', 'vicodin')],
                			['block_title' => esc_html__('Breathing Valve', 'vicodin')],
                			['block_title' => esc_html__('6 Layer Filteration', 'vicodin')],
                			['block_title' => esc_html__('Rewashes & Reusable', 'vicodin')],
            			],
            		'fields' => 
						[
                			[
                    			'name' => 'icons',
                    			'label' => esc_html__('Enter The icons', 'vicodin'),
								'label_block' => true,
                    			'type' => Controls_Manager::SELECT2,
                    			'options'  => get_fontawesome_icons(),
                			],
							[
                    			'name' => 'block_title',
                    			'label' => esc_html__('Title', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
						],
            	    'title_field' => '{{block_title}}',
                 ]
        );
		$this->add_control(
			'btn_title',
			[
				'label'       => __( 'Button Title', 'vicodin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'vicodin' ),
			]
		);
		$this->add_control(
			'btn_link',
				[
				  'label' => __( 'Button Url', 'vicodin' ),
				  'type' => Controls_Manager::URL,
				  'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
				  'show_external' => true,
				  'default' => [
				    'url' => '',
				    'is_external' => true,
				    'nofollow' => true,
				  ],
			 ]
		);
		$this->end_controls_section();
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
    ?>
	        
    <!-- ABOUT US AREA START -->
    <div class="<?php if($settings['style_two'] == 'two') echo 'ltn__about-us-area bg-image pt-115 pb-110'; else echo 'ltn__about-us-area section-bg-1 bg-image-left-before pt-115 pb-115'; ?>" <?php if($settings['style_two'] == 'two'){ ?>data-bs-bg="<?php echo esc_url(wp_get_attachment_url($settings['bg_image']['id'])); ?>"<?php } ?>>
        <div class="container">
            <div class="row">
                <div class="col-lg-6 align-self-center">
                    <div class="about-us-img-wrap about-img-left---">
                        <!-- <img src="img/others/7.png" alt="About Us Image"> -->
                    </div>
                </div>
                <div class="col-lg-6 align-self-center">
                    <div class="about-us-info-wrap">
                         <?php if($settings['subtitle'] || $settings['title'] || $settings['text']) { ?>
                        <div class="section-title-area ltn__section-title-2--- mb-20">
                             <?php if($settings['subtitle']) { ?><h6 class="section-subtitle section-subtitle-2--- ltn__secondary-color"><?php echo wp_kses($settings['subtitle'], true);?></h6><?php } ?>
                             <?php if($settings['title']) { ?><h1 class="section-title"><?php echo wp_kses($settings['title'], true);?></h1><?php } ?>
                             <?php if($settings['text']) { ?><p><?php echo wp_kses($settings['text'], true);?></p><?php } ?>
                        </div>
                        <?php } ?>
                        <ul class="ltn__list-item-half clearfix">
                           <?php foreach($settings['features'] as $key => $item): ?>
                            <li>
                                <i class="<?php echo wp_kses(str_replace( "icon ",  "", $item['icons']), true);?>"></i>
                                <?php echo wp_kses($item['block_title'], true);?>
                            </li>
                            <?php endforeach; ?>
                        </ul>
                        <?php if($settings['btn_link']['url'] and $settings['btn_title']){ ?>
                        <div class="btn-wrapper animated">
                            <a href="<?php echo esc_url($settings['btn_link']['url']); ?>" class="ltn__secondary-color text-uppercase text-decoration-underline"><?php echo wp_kses($settings['btn_title'], true);?></a>
                        </div>
                         <?php } ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- ABOUT US AREA END -->
    
    <?php
    }
}
