<?php namespace VICODINPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Faqs extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'vicodin_faqs';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Faqs', 'vicodin' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-library-open';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'vicodin' ];
    }

    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'faqs',
            [
                'label' => esc_html__( 'Faqs', 'vicodin' ),
            ]
        );
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'vicodin' ),
			]
		);
		$this->add_control(
           'features', 
			  	[
            		'type' => Controls_Manager::REPEATER,
            		'separator' => 'before',
            		'default' => 
						[
                			['block_title' => esc_html__('How to buy a product?', 'vicodin')],
                			['block_title' => esc_html__('How can i make refund from your website?', 'vicodin')],
                			['block_title' => esc_html__('I am a new user. How should I start?', 'vicodin')],
                			['block_title' => esc_html__('Returns and refunds', 'vicodin')],
                			['block_title' => esc_html__('Are my details secured?', 'vicodin')],
            			],
            		'fields' => 
						[
							[
                    			'name' => 'block_title',
                    			'label' => esc_html__('Title', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'block_text',
                    			'label' => esc_html__('Text', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
								'name' => 'video_image',
								'label' => __( 'Video Image', 'vicodin' ),
								'type' => Controls_Manager::MEDIA,
								'default' => ['url' => Utils::get_placeholder_image_src(),],
							],
							[
								  'name' => 'video_link',
								  'label' => __( 'Video Url', 'vicodin' ),
								  'type' => Controls_Manager::URL,
								  'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
								  'show_external' => true,
								  'default' => [
									'url' => '',
									'is_external' => true,
									'nofollow' => true,
								  ],
							 ],
						],
            	    'title_field' => '{{block_title}}',
                 ]
        );
		$this->add_control(
			'feature_image',
			[
				'label' => __( 'Feature Image', 'vicodin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->end_controls_section();
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
        ?>
		
       
    <!-- FAQ AREA START (faq-2) (ID > accordion_2) -->
    <div class="ltn__faq-area pt-115 pb-120">
        <div class="container">
            <?php if($settings['title']) { ?>
            <div class="row">
                <div class="col-lg-12">
                    <div class="section-title-area ltn__section-title-2 text-center">
                        <h1 class="section-title white-color---"><?php echo wp_kses($settings['title'], true);?></h1>
                    </div>
                </div>
            </div>
            <?php } ?>
            <div class="row">
                <div class="col-lg-6">
                    <div class="ltn__faq-inner ltn__faq-inner-2">
                        <div id="accordion_2">
                           	<?php $count = 1; foreach($settings['features'] as $key => $item): ?> 
                            <!-- card -->
                            <div class="card">
                                <h6 class="ltn__card-title" data-bs-toggle="collapse" data-bs-target="#faq-item-2-<?php echo esc_attr($count); ?>" aria-expanded="<?php if($count == 2) echo 'true'; else echo 'false'; ?>"> 
                                   <?php echo wp_kses($item['block_title'], true);?>
                                </h6>
                                <div id="faq-item-2-<?php echo esc_attr($count); ?>" class="collapse <?php if($count == 2) echo 'show' ?>" data-bs-parent="#accordion_2">
                                    <div class="card-body">
                                        <?php if($item['video_image']['id']){ ?>
                                        <div class="ltn__video-img alignleft">
                                            <img src="<?php echo esc_url(wp_get_attachment_url($item['video_image']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'vicodin'); ?>">
                                            <?php if($item['video_link']['url']){ ?>
                                            <a class="ltn__video-icon-2 ltn__video-icon-2-small ltn__video-icon-2-border----" href="<?php echo esc_url($item['video_link']['url']); ?>"  data-rel="lightcase:myCollection">
                                                <i class="fa fa-play"></i>
                                            </a>
                                            <?php } ?>
                                        </div>
                                         <?php } ?>
                                        <p><?php echo wp_kses($item['block_text'], true);?></p>
                                    </div>
                                </div>
                            </div>  
                            <?php $count++; endforeach; ?>                      
                        </div>
                    </div>
                </div>
                <div class="col-lg-6">
                   	<?php if($settings['feature_image']['id']){ ?>
                    <aside class="about-us-img-wrap about-img-right">
                        <img src="<?php echo esc_url(wp_get_attachment_url($settings['feature_image']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'vicodin'); ?>">
                    </aside>
                     <?php } ?>
                </div>
            </div>
        </div>
    </div>
    <!-- FAQ AREA START --> 
       
     
        
       
       
       
             
        <?php
    }
}
