<?php namespace VICODINPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Faqs_V2 extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'vicodin_faqs_v2';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Faqs V2', 'vicodin' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-library-open';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'vicodin' ];
    }

    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'faqs_v2',
            [
                'label' => esc_html__( 'Faqs V2', 'vicodin' ),
            ]
        );
		$this->add_control(
           'features', 
			  	[
            		'type' => Controls_Manager::REPEATER,
            		'separator' => 'before',
            		'default' => 
						[
                			['block_title' => esc_html__('How to buy a product?', 'vicodin')],
                			['block_title' => esc_html__('How can i make refund from your website?', 'vicodin')],
                			['block_title' => esc_html__('I am a new user. How should I start?', 'vicodin')],
                			['block_title' => esc_html__('Returns and refunds', 'vicodin')],
                			['block_title' => esc_html__('Are my details secured?', 'vicodin')],
            			],
            		'fields' => 
						[
							[
                    			'name' => 'block_title',
                    			'label' => esc_html__('Title', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'block_text',
                    			'label' => esc_html__('Text', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
								'name' => 'video_image',
								'label' => __( 'Video Image', 'vicodin' ),
								'type' => Controls_Manager::MEDIA,
								'default' => ['url' => Utils::get_placeholder_image_src(),],
							],
							[
								  'name' => 'video_link',
								  'label' => __( 'Video Url', 'vicodin' ),
								  'type' => Controls_Manager::URL,
								  'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
								  'show_external' => true,
								  'default' => [
									'url' => '',
									'is_external' => true,
									'nofollow' => true,
								  ],
							 ],
						],
            	    'title_field' => '{{block_title}}',
                 ]
        );
		$this->add_control(
			'contact_title',
			[
				'label'       => __( 'Contact Title', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'vicodin' ),
			]
		);
		$this->add_control(
			'btn_title',
			[
				'label'       => __( 'Button Title', 'vicodin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'vicodin' ),
			]
		);
		$this->add_control(
			'btn_link',
				[
				  'label' => __( 'Button Url', 'vicodin' ),
				  'type' => Controls_Manager::URL,
				  'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
				  'show_external' => true,
				  'default' => [
				    'url' => '',
				    'is_external' => true,
				    'nofollow' => true,
				  ],
			 ]
		);
		$this->add_control(
			'phone_no',
			[
				'label'       => __( 'Phone Number', 'vicodin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Phone Number', 'vicodin' ),
			]
		);
		$this->add_control(
			'newsletter_subtitle',
			[
				'label'       => __( 'Newsletter Sub Title', 'vicodin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your newsletter subtitle', 'vicodin' ),
			]
		);
		$this->add_control(
			'newsletter_title',
			[
				'label'       => __( 'Newsletter Title', 'vicodin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your newsletter title', 'vicodin' ),
			]
		);
		$this->add_control(
			'newsletter_form_url',
			[
				'label'       => __( 'Newsletter Form Url', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your newsletter form url', 'vicodin' ),
			]
		);
		
		$this->add_control(
			'show_mask_protection_area',
			[
				'label'       => __( 'Enable/Disable Mask Protection Area', 'vicodin' ),
                'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'vicodin' ),
				'label_off' => __( 'Hide', 'vicodin' ),
				'return_value' => 'yes',
				'default' => 'no',
				
			]
		);
		$this->add_control(
			'block_subtitle',
			[
				'label'       => __( 'Mask Box Sub Title', 'vicodin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Mask Box Sub title', 'vicodin' ),
				'condition' => [
					'show_mask_protection_area' => 'yes',
				],
			]
		);
		$this->add_control(
			'block_title',
			[
				'label'       => __( 'Mask Box Title', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Mask Box Title', 'vicodin' ),
				'condition' => [
					'show_mask_protection_area' => 'yes',
				],
			]
		);
		$this->add_control(
			'block_btn_title',
			[
				'label'       => __( 'Button Title', 'vicodin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button title', 'vicodin' ),
				'condition' => [
					'show_mask_protection_area' => 'yes',
				],
			]
		);
		$this->add_control(
			'block_btn_link',
				[
				  'label' => __( 'Button Url', 'vicodin' ),
				  'type' => Controls_Manager::URL,
				  'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
				  'show_external' => true,
				  'default' => [
				    'url' => '',
				    'is_external' => true,
				    'nofollow' => true,
				 ],
				 'condition' => [
					'show_mask_protection_area' => 'yes',
				 ],
			 ]
		);
		$this->add_control(
			'feature_image',
			[
				'label' => __( 'Feature Image', 'vicodin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
				'condition' => [
					'show_mask_protection_area' => 'yes',
				],
			]
		);
		$this->end_controls_section();
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
    ?>
	
    <!-- FAQ AREA START (faq-2) (ID > accordion_2) -->
    <div class="ltn__faq-area mb-100">
        <div class="container">
            <div class="row">
                <div class="col-lg-8">
                    <div class="ltn__faq-inner ltn__faq-inner-2">
                        <div id="accordion_2">
							<?php $count = 1; foreach($settings['features'] as $key => $item): ?> 
                            <!-- card -->
                            <div class="card">
                                <h6 class="ltn__card-title" data-bs-toggle="collapse" data-bs-target="#faq-item-2-<?php echo esc_attr($count); ?>" aria-expanded="<?php if($count == 2) echo 'true'; else echo 'false'; ?>"> 
                                   <?php echo wp_kses($item['block_title'], true);?>
                                </h6>
                                <div id="faq-item-2-<?php echo esc_attr($count); ?>" class="collapse <?php if($count == 2) echo 'show' ?>" data-bs-parent="#accordion_2">
                                    <div class="card-body">
                                        <?php if($item['video_image']['id']){ ?>
                                        <div class="ltn__video-img alignleft">
                                            <img src="<?php echo esc_url(wp_get_attachment_url($item['video_image']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'vicodin'); ?>">
                                            <?php if($item['video_link']['url']){ ?>
                                            <a class="ltn__video-icon-2 ltn__video-icon-2-small ltn__video-icon-2-border----" href="<?php echo esc_url($item['video_link']['url']); ?>"  data-rel="lightcase:myCollection">
                                                <i class="fa fa-play"></i>
                                            </a>
                                            <?php } ?>
                                        </div>
                                         <?php } ?>
                                        <p><?php echo wp_kses($item['block_text'], true);?></p>
                                    </div>
                                </div>
                            </div>  
                            <?php $count++; endforeach; ?> 
                        </div>
                        <div class="need-support text-center mt-100">
                            <?php if($settings['contact_title']) { ?><h2><?php echo wp_kses($settings['contact_title'], true);?></h2><?php } ?>
                           	<?php if($settings['btn_link']['url'] || $settings['btn_title']){ ?>
                            <div class="btn-wrapper mb-30">
                                <a href="<?php echo esc_url($settings['btn_link']['url']); ?>" class="theme-btn-1 btn"><?php echo wp_kses($settings['btn_title'], true);?></a>
                            </div>
                            <?php } ?>
                            <?php if($settings['phone_no']) { ?><h3><i class="fas fa-phone"></i> <?php echo wp_kses($settings['phone_no'], true);?></h3><?php } ?>
                        </div>
                    </div>
                </div>
                <div class="col-lg-4">
                    <aside class="sidebar-area ltn__right-sidebar">
                        <?php if($settings['newsletter_subtitle'] || $settings['newsletter_title'] || $settings['newsletter_form_url']) { ?>
                        <!-- Newsletter Widget -->
                        <div class="widget ltn__search-widget ltn__newsletter-widget">                            
                            <?php if($settings['newsletter_subtitle']) { ?><h6 class="ltn__widget-sub-title"><?php echo wp_kses($settings['newsletter_subtitle'], true);?></h6><?php } ?>
                            <?php if($settings['newsletter_title']) { ?><h4 class="ltn__widget-title"><?php echo wp_kses($settings['newsletter_title'], true);?></h4><?php } ?>
                            
							<?php echo do_shortcode($settings['newsletter_form_url'], true);?>
                            
                            <div class="ltn__newsletter-bg-icon">
                                <i class="fas fa-envelope-open-text"></i>
                            </div>
                        </div>
                        <?php } ?>
                        
                        <?php if($settings['show_mask_protection_area']) { ?>
                        <!-- Mask Block -->
						<div class="mask-block">
							<div class="inner-box">
								<div class="content">
									<div class="title"><?php echo wp_kses($settings['block_subtitle'], true);?></div>
									<h2>
										<?php echo wp_kses($settings['block_title'], true);?>
									</h2>
									<a class="buy-now" href="<?php echo esc_url($settings['block_btn_link']['url']);?>"><?php echo wp_kses($settings['block_btn_title'], true);?></a>
								</div>
								<?php if($settings['feature_image']['id']){ ?>
                                <div class="image-outer">
									<div class="image">
										<div class="circle-layer"></div>
										<img src="<?php echo esc_url(wp_get_attachment_url($settings['feature_image']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'vicodin'); ?>">
									</div>
								</div>
                                <?php } ?>
							</div>
						</div>
                        <?php } ?>
                    </aside>
                </div>
            </div>
        </div>
    </div>
    <!-- FAQ AREA START -->
          
    <?php
    }
}
