<?php namespace VICODINPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Feature_Product extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'vicodin_feature_product';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Feature Product', 'vicodin' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-library-open';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'vicodin' ];
    }

    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'feature_product',
            [
                'label' => esc_html__( 'Feature Product', 'vicodin' ),
            ]
        );
		$this->add_control(
        	'features', 
			[
				'type' => Controls_Manager::REPEATER,
				'separator' => 'before',
				'default' => 
					[
						['subtitle' => esc_html__('Hot Sales', 'vicodin')],
						['subtitle' => esc_html__('Sanitzer', 'vicodin')],
						['subtitle' => esc_html__('Sanitzer', 'vicodin')],	
					],
				'fields' => 
					[
						[
							'name' => 'subtitle',
							'label' => esc_html__('Sub Title', 'vicodin'),
							'label_block' => true,
							'type' => Controls_Manager::TEXT,
							'default' => esc_html__('', 'vicodin')
						],
						[
							'name' => 'title',
							'label' => esc_html__('Title', 'vicodin'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'vicodin')
						],
						[
							'name' => 'btn_title',
							'label' => esc_html__('Button Title', 'vicodin'),
							'label_block' => true,
							'type' => Controls_Manager::TEXT,
							'default' => esc_html__('Read More', 'vicodin')
						],
						[
							'name' => 'btn_link',
							'label' => __( 'Button Link', 'vicodin' ),
							'type' => Controls_Manager::URL,
							'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
							'show_external' => true,
							'default' => ['url' => '','is_external' => true,'nofollow' => true,],
						],
						[
							'name' => 'feature_image',
							'label' => esc_html__('Feature Image', 'vicodin'),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],
						[
							'name' => 'style_two',
							'label'   => esc_html__( 'Choose Different Style', 'vicodin' ),
							'label_block' => true,
							'type'    => Controls_Manager::SELECT,
							'default' => 'one',
							'options' => array(
								'one' => esc_html__( 'Choose Style One', 'vicodin' ),
								'two'  => esc_html__( 'Choose Style Two', 'vicodin' ),
								'three'  => esc_html__( 'Choose Style Three', 'vicodin' ),
							),
						],
					],
				  'title_field' => '{{subtitle}}',
			 ]
        );
		$this->end_controls_section();
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
    ?>
	
    <!-- BANNER AREA START -->
    <div class="ltn__banner-area mt-120---">
        <div class="container">
            <div class="row ltn__custom-gutter--- justify-content-center">
                <?php foreach($settings['features'] as $key => $item): ?>
                <div class="col-lg-4 col-sm-6">
					<!-- Sale Block -->
                    <div class="sale-block <?php if($item['style_two'] == 'three') echo 'style-three'; elseif($item['style_two'] == 'two') echo 'style-two'; else echo ''; ?>">
						<div class="inner-box">
							<div class="content">
								<div class="title"><?php echo wp_kses($item['subtitle'], true);?></div>
								<h2>
									<?php echo wp_kses($item['title'], true);?>
								</h2>
								<?php if($item['btn_link']['url']){ ?>
                                <a class="buy-now" href="<?php echo esc_url($item['btn_link']['url']);?>"><?php echo wp_kses($item['btn_title'], true);?></a>
                                <?php } ?>
							</div>
							<?php if($item['feature_image']['id']){ ?>
                            <div class="image-outer">
								<div class="image">
									<div class="circle-layer"></div>
									<img src="<?php echo esc_url(wp_get_attachment_url($item['feature_image']['id']));?>" alt="<?php esc_attr_e('Awesome Image', 'vicodin'); ?>">
								</div>
							</div>
                            <?php } ?>
						</div>
                    </div>
                </div>
                <?php endforeach;?>
            </div>
        </div>
    </div>
    <!-- BANNER AREA END -->
    
    <?php
    }
}
