<?php

namespace VICODINPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Feature_Product_V2 extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'vicodin_feature_product_v2';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Feature Product V2', 'vicodin' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-library-open';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'vicodin' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'feature_product_v2',
			[
				'label' => esc_html__( 'Feature Product V2', 'vicodin' ),
			]
		);
		$this->add_control(
			'style_two',
			[
				'label'   => esc_html__( 'Choose Different Style', 'vicodin' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'one',
				'options' => array(
					'one' => esc_html__( 'Choose Style V1', 'vicodin' ),
					'two' => esc_html__( 'Choose Style V2 ', 'vicodin' ),
				),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'vicodin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'vicodin' ),
			]
		);
		$this->add_control(
        	'features', 
			[
				'type' => Controls_Manager::REPEATER,
				'separator' => 'before',
				'default' => 
					[
						['subtitle1' => esc_html__('Hot Sales', 'vicodin')],
						['subtitle1' => esc_html__('Sanitzer', 'vicodin')],
					],
				'fields' => 
					[
						[
							'name' => 'subtitle1',
							'label' => esc_html__('Sub Title', 'vicodin'),
							'label_block' => true,
							'type' => Controls_Manager::TEXT,
							'default' => esc_html__('', 'vicodin')
						],
						[
							'name' => 'title1',
							'label' => esc_html__('Title', 'vicodin'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'vicodin')
						],
						[
							'name' => 'btn_title',
							'label' => esc_html__('Button Title', 'vicodin'),
							'label_block' => true,
							'type' => Controls_Manager::TEXT,
							'default' => esc_html__('Read More', 'vicodin')
						],
						[
							'name' => 'btn_link',
							'label' => __( 'Button Link', 'vicodin' ),
							'type' => Controls_Manager::URL,
							'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
							'show_external' => true,
							'default' => ['url' => '','is_external' => true,'nofollow' => true,],
						],
						[
							'name' => 'feature_image',
							'label' => esc_html__('Feature Image', 'vicodin'),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],
						[
							'name' => 'new_style',
							'label'   => esc_html__( 'Choose Different Style', 'vicodin' ),
							'label_block' => true,
							'type'    => Controls_Manager::SELECT,
							'default' => 'one',
							'options' => array(
								'one' => esc_html__( 'Choose BG Color Style One', 'vicodin' ),
								'two'  => esc_html__( 'Choose BG Color Style Two', 'vicodin' ),
							),
						],
					],
				'title_field' => '{{subtitle1}}',
        	]
        );
		$this->add_control(
			'query_number',
			[
				'label'   => esc_html__( 'Number of post', 'vicodin' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 3,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_orderby',
			[
				'label'   => esc_html__( 'Order By', 'vicodin' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => array(
					'date'       => esc_html__( 'Date', 'vicodin' ),
					'title'      => esc_html__( 'Title', 'vicodin' ),
					'menu_order' => esc_html__( 'Menu Order', 'vicodin' ),
					'rand'       => esc_html__( 'Random', 'vicodin' ),
				),
			]
		);
		$this->add_control(
			'query_order',
			[
				'label'   => esc_html__( 'Order', 'vicodin' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => array(
					'DESC' => esc_html__( 'DESC', 'vicodin' ),
					'ASC'  => esc_html__( 'ASC', 'vicodin' ),
				),
			]
		);
		$this->add_control(
            'query_category', 
			[
			  'type' => Controls_Manager::SELECT,
			  'label' => esc_html__('Category', 'vicodin'),
			  'options' => get_product_categories(),
			  'label_block' => true,
			]
		);
		$this->end_controls_section();
	}
	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
		
        $paged = get_query_var('paged');
		$paged = vicodin_set($_REQUEST, 'paged') ? esc_attr($_REQUEST['paged']) : $paged;

		$this->add_render_attribute( 'wrapper', 'class', 'themexriver-vicodin' );
		$args = array(
			'post_type'      => 'product',
			'posts_per_page' => vicodin_set( $settings, 'query_number' ),
			'orderby'        => vicodin_set( $settings, 'query_orderby' ),
			'order'          => vicodin_set( $settings, 'query_order' ),
			'paged'         => $paged
		);
		
		if( vicodin_set( $settings, 'query_category' ) ) $args['product_cat'] = vicodin_set( $settings, 'query_category' );
		$query = new \WP_Query( $args );

		if ( $query->have_posts() ) 
	{ ?>
		
    <!-- PRODUCT AREA START (product-item-3) -->
    <div class="woocommerce ltn__product-area ltn__product-gutter  no-product-ratting  pb-70 <?php if($settings['style_two'] == 'two') echo 'pt-20--- pt-65'; else echo 'pt-85'; ?>">
        <div class="container">
            <div class="row">
                <div class="col-lg-12">
                    <?php if($settings['title']){ ?>
                    <div class="section-title-area ltn__section-title-2 text-center">
                        <h1 class="section-title"><?php echo wp_kses($settings['title'], true);?></h1>
                    </div>
                    <?php }?>
                </div>
            </div>
            <div class="row">
                <div class="col-lg-3">
                    <div class="row">
                        <?php foreach($settings['features'] as $key => $item): ?>
                        <div class="col-lg-12 col-sm-6">
							
							<!-- Featured Block -->
							<div class="featured-block <?php if($item['new_style'] == 'two') echo 'style-two'; else echo ''; ?>">
								<div class="inner-box">
									<div class="content">
										<div class="title"><?php echo wp_kses($item['subtitle1'], true);?></div>
										<h5><?php echo wp_kses($item['title1'], true);?></h5>
										<?php if($item['btn_link']['url']){ ?>
                                        <a class="buy-now" href="<?php echo esc_url($item['btn_link']['url']);?>"><?php echo wp_kses($item['btn_title'], true);?></a>
                                        <?php } ?>
									</div>
									<?php if($item['feature_image']['id']){ ?>
                                    <div class="image-outer">
										<div class="image">
											<img src="<?php echo esc_url(wp_get_attachment_url($item['feature_image']['id']));?>" alt="<?php esc_attr_e('Awesome Image', 'vicodin'); ?>">
										</div>
									</div>
                                    <?php } ?>
								</div>
							</div>
							
                        </div>
                        <?php endforeach;?>
                    </div>
                </div>
                <div class="col-lg-9">
                    <div class="row ltn__tab-product-slider-one-active--- slick-arrow-1">
                        <?php 
							global $post;
							while ( $query->have_posts() ) : $query->the_post(); 
							$post_thumbnail_id = get_post_thumbnail_id($post->ID);
							$post_thumbnail_url = wp_get_attachment_url( $post_thumbnail_id );
						?>
                        <!-- ltn__product-item -->
                        <div class="col-lg-3--- col-md-4 col-sm-6 col-6">
                            <div class="ltn__product-item ltn__product-item-2 text-left">
                                <div class="product-img">
                                    <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_post_thumbnail('vicodin_600x701'); ?></a>
                                    <div class="product-hover-action">
                                        <ul>
                                            <li>
                                                <a href="<?php echo esc_url($post_thumbnail_url); ?>" data-rel="lightcase:myCollection">
                                                    <i class="far fa-eye"></i>
                                                </a>
                                            </li>
                                            <li>
                                                <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>">
                                                    <i class="fas fa-shopping-cart"></i>
                                                </a>
                                            </li>
                                        </ul>
                                    </div>
                                </div>
                                <div class="product-info">
                                    <div class="product-ratting">
                                       <?php woocommerce_template_loop_rating();?>
                                    </div>
                                    <h2 class="product-title"><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h2>
                                    <div class="product-price">
                                        <?php woocommerce_template_loop_price();?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <?php endwhile; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- PRODUCT AREA END -->

	<?php }
	wp_reset_postdata();
	}
}