<?php namespace VICODINPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Funfacts extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'vicodin_funfacts';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Funfacts', 'vicodin' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-library-open';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'vicodin' ];
    }

    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'funfacts',
            [
                'label' => esc_html__( 'Funfacts', 'vicodin' ),
            ]
        );
		$this->add_control(
			'bg_image',
			[
				'label' => __( 'Background Image', 'vicodin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
              'funfact', 
			  	[
            		'type' => Controls_Manager::REPEATER,
            		'separator' => 'before',
            		'default' => 
						[
                			['block_title' => esc_html__('Active Clients', 'vicodin')],
                			['block_title' => esc_html__('Cup Of Coffee', 'vicodin')],
							['block_title' => esc_html__('Get Rewards', 'vicodin')],
							['block_title' => esc_html__('Country Cover', 'vicodin')],
            			],
            		'fields' => 
						[
							[
                    			'name' => 'icons',
                    			'label' => esc_html__('Enter The icons', 'vicodin'),
								'label_block' => true,
                    			'type' => Controls_Manager::SELECT2,
                    			'options'  => get_fontawesome_icons(),
                			],
							[
                    			'name' => 'counter_stop',
                    			'label' => esc_html__('Count Stop Value', 'vicodin'),
								'label_block' => true,
                    			'type' => Controls_Manager::TEXT,
								'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'alphabet_letter',
                    			'label' => esc_html__('Alphabet Letters', 'vicodin'),
								'label_block' => true,
                    			'type' => Controls_Manager::TEXT,
								'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'alphabet_symbol',
                    			'label' => esc_html__('Alphabet Symbol', 'vicodin'),
								'label_block' => true,
                    			'type' => Controls_Manager::TEXT,
								'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'block_title',
                    			'label' => esc_html__('Title', 'vicodin'),
								'label_block' => true,
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
						],
            	    'title_field' => '{{block_title}}',
                 ]
        );
		$this->end_controls_section();
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
        ?>
		
      <!-- COUNTER UP AREA START -->
    <div class="ltn__counterup-area section-bg-1 bg-image bg-overlay-theme-black-80--- pt-115 pb-70" <?php if($settings['bg_image']['id']){ ?> data-bs-bg="<?php echo esc_url(wp_get_attachment_url($settings['bg_image']['id'])); ?>"<?php } ?>>
        <div class="container">
            <div class="row">
               	 <?php foreach($settings['funfact'] as $key => $item): ?>
                <div class="col-md-3 col-sm-6 align-self-center">
                    <div class="ltn__counterup-item text-center">
                        <div class="counter-icon"> 
                            <!-- <img src="img/icons/icon-img/2.png" alt="#">  -->
                            <i class="<?php echo wp_kses(str_replace( "icon ",  "", $item['icons']), true);?>"></i>
                        </div>
                        <h1><span class="counter"><?php echo esc_attr($item['counter_stop']);?></span><span class="counterUp-letter"><?php echo esc_attr($item['alphabet_letter']);?></span><span class="counterUp-icon"><?php echo esc_attr($item['alphabet_symbol']);?></span> </h1>
                        <h6><?php echo wp_kses($item['block_title'], true);?></h6>
                    </div>
                </div>
                 <?php endforeach; ?>
            </div>
        </div>
    </div>
    <!-- COUNTER UP AREA END -->

        
     
                 
        <?php
    }
}
