<?php namespace VICODINPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class History_Tabs extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'vicodin_history_tabs';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'History Tabs', 'vicodin' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-library-open';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'vicodin' ];
    }

    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'history_tabs',
            [
                'label' => esc_html__( 'History Tabs', 'vicodin' ),
            ]
        );
		$this->add_control(
              'our_tabs', 
			  	[
            		'type' => Controls_Manager::REPEATER,
            		'separator' => 'before',
            		'default' => 
						[
                			['tab_title' => esc_html__('1900', 'vicodin')],
                			['tab_title' => esc_html__('1940', 'vicodin')],
                			['tab_title' => esc_html__('2000', 'vicodin')],
                			['tab_title' => esc_html__('2010', 'vicodin')],
                 			['tab_title' => esc_html__('2021', 'vicodin')],
           			],
            		'fields' => 
						[
							[
                    			'name' => 'tab_title',
                    			'label' => esc_html__('Tab Title', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
								'name' => 'feature_image',
								'label' => esc_html__('Feature Image', 'vicodin'),
								'type' => Controls_Manager::MEDIA,
								'default' => ['url' => Utils::get_placeholder_image_src(),],
							],
							[
								'name' => 'icons',
								'label' => esc_html__('Enter The icons', 'vicodin'),
								'label_block' => true,
								'type' => Controls_Manager::SELECT2,
								'options'  => get_fontawesome_icons(),
							],	
							[
                    			'name' => 'block_subtitle',
                    			'label' => esc_html__('Sub Title', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'block_title',
                    			'label' => esc_html__('Title', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'block_text',
                    			'label' => esc_html__('Text', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'block_text1',
                    			'label' => esc_html__('Text 1', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
						],
            	    'title_field' => '{{tab_title}}',
                 ]
        );
		$this->end_controls_section();
    }
    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
        ?>
		
       
       <!-- OUR HISTORY AREA START -->
    <div class="ltn__our-history-area pb-100">
        <div class="container">
            <div class="row">
                <div class="col-lg-12">
                    <div class="ltn__our-history-inner">
                        <div class="ltn__tab-menu text-uppercase">
                            <div class="nav">
                                <?php $count = 1; foreach($settings['our_tabs'] as $key => $item): ?>
                                <a class="<?php if($count == 2) echo 'active show'; ?>" data-bs-toggle="tab" href="#liton_tab_2_<?php echo esc_attr($count);?>"><?php echo wp_kses($item['tab_title'], true);?></a>
                                <?php $count++; endforeach; ?>
                            </div>
                        </div>
                        <div class="tab-content">
                            <?php $count = 1; foreach($settings['our_tabs'] as $key => $item): ?>
                            <div class="tab-pane fade <?php if($count == 2) echo 'active show'; ?>" id="liton_tab_2_<?php echo esc_attr($count);?>">
                                <div class="ltn__product-tab-content-inner">
                                    <div class="row">
                                        <div class="col-lg-6 align-self-center">
                                            <div class="about-us-img-wrap about-img-left">
                                                <?php if($item['feature_image']['id']){ ?>
                                                <img src="<?php echo esc_url(wp_get_attachment_url($item['feature_image']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'vicodin'); ?>">
                                                <?php } ?>
                                                <?php if($item['icons']){ ?>
                                                <div class="ltn__history-icon">
                                                    <i class="<?php echo wp_kses(str_replace( "icon ",  "", $item['icons']), true);?>"></i>
                                                </div>
                                                <?php } ?>
                                            </div>
                                        </div>
                                        <div class="col-lg-6 align-self-center">
                                            <div class="about-us-info-wrap">
                                                <?php if($item['block_subtitle'] || $item['block_title'] || $item['block_text']){ ?>
                                                <div class="section-title-area ltn__section-title-2--- text-center---">
                                                     <?php if($item['block_subtitle']){ ?><h6 class="section-subtitle section-subtitle-2 ltn__secondary-color"><?php echo wp_kses($item['block_subtitle'], true);?></h6><?php } ?>
                                                     <?php if($item['block_title']){ ?><h1 class="section-title"><?php echo wp_kses($item['block_title'], true);?></h1><?php } ?>
                                                     <?php if($item['block_text']){ ?><p><?php echo wp_kses($item['block_text'], true);?></p><?php } ?>
                                                </div>
												<?php } ?>
                                                <?php if($item['block_text1']){ ?>
                                                <p><?php echo wp_kses($item['block_text1'], true);?></p>
                                                <?php } ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                           <?php $count++; endforeach; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- OUR HISTORY AREA END -->
       
       
       
       
       
        <?php
    }
}
