<?php 

namespace VICODINPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Our_Product extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'vicodin_our_product';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Our Product', 'vicodin' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-library-open';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'vicodin' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'our_product',
			[
				'label' => esc_html__( 'Our Product', 'vicodin' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'About Title', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title Here', 'vicodin' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Text', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Text Here', 'vicodin' ),
			]
		);
		$this->add_control(
              'feature_tab', 
			  	[
            		'type' => Controls_Manager::REPEATER,
            		'separator' => 'before',
					'default' => 
						[
                			['btn_title' => esc_html__('Equipment', 'vicodin')],
                			['btn_title' => esc_html__('Medicine', 'vicodin')],
							['btn_title' => esc_html__('Sanitizer', 'vicodin')],
							['btn_title' => esc_html__('Safety-suits', 'vicodin')],
 							['btn_title' => esc_html__('Face-mask ', 'vicodin')],
          			],
            		'fields' => 
					[
						
						[
							'name' => 'btn_title',
							'label' => esc_html__('Tab Button Title', 'vicodin'),
							'label_block' => true,
							'type' => Controls_Manager::TEXT,
							'default' => esc_html__('', 'vicodin')
						],
						[
							'name' => 'text_limit',
							'label'   => esc_html__( 'Number of Text', 'vicodin' ),
							'type'    => Controls_Manager::NUMBER,
							'default' => 3,
							'min'     => 1,
							'max'     => 100,
							'step'    => 1,
						],
						[
							'name' => 'query_number',
							'label'   => esc_html__( 'Number of post', 'vicodin' ),
							'type'    => Controls_Manager::NUMBER,
							'default' => 3,
							'min'     => 1,
							'max'     => 100,
							'step'    => 1,
						],
						[
							'name' => 'query_orderby',
							'label'   => esc_html__( 'Order By', 'vicodin' ),
							'label_block' => true,
							'type'    => Controls_Manager::SELECT,
							'default' => 'date',
							'options' => array(
								'date'       => esc_html__( 'Date', 'vicodin' ),
								'title'      => esc_html__( 'Title', 'vicodin' ),
								'menu_order' => esc_html__( 'Menu Order', 'vicodin' ),
								'rand'       => esc_html__( 'Random', 'vicodin' ),
							),
						],
						[
							'name' => 'query_order',
							'label'   => esc_html__( 'Order', 'vicodin' ),
							'label_block' => true,
							'type'    => Controls_Manager::SELECT,
							'default' => 'DESC',
							'options' => array(
								'DESC' => esc_html__( 'DESC', 'vicodin' ),
								'ASC'  => esc_html__( 'ASC', 'vicodin' ),
							),
						],
						[
							'name' => 'query_category',
							'type' => Controls_Manager::SELECT,
							'label' => esc_html__('Category', 'vicodin'),
							'label_block' => true,
							'options' => get_product_categories()
						],
					],
				'title_field' => '{{btn_title}}',
			 ]
        );
		$this->add_control(
			'style_two',
			 [
				'label'   => esc_html__( 'Choose Different Style', 'eminent' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'one',
				'options' => array(
				'one' => esc_html__( 'Choose Gray Background Style', 'eminent' ),
				'two'  => esc_html__( 'Choose Wight Background Style', 'eminent' ),
				),
			 ]
		);
		$this->end_controls_section();
	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 protected function render() {
		$settings = $this->get_settings_for_display();
		
	?>

	
     <!-- PRODUCT TAB AREA START (product-item-3) -->
    <div class="woocommerce ltn__product-tab-area ltn__product-gutter pt-115 pb-70">
        <div class="container">
            <div class="row">
                <div class="col-lg-12">
                    <?php if($settings['style_two'] == 'two') : ?>
					<?php if($settings['text'] || $settings['title']){ ?>
                    <div class="section-title-area ltn__section-title-2--- text-center">
                        <?php if($settings['title']){ ?><h1 class="section-title"><?php echo wp_kses($settings['title'], true); ?></h1><?php } ?>
                        <?php if($settings['text']){ ?><p><?php echo wp_kses($settings['text'], true); ?></p><?php } ?>
                    </div>
                    <?php } ?>
                    <?php endif; ?>
                    <div class="ltn__tab-menu ltn__tab-menu-2 ltn__tab-menu-top-right-- text-uppercase text-center">
                        <div class="nav">
                            <?php $count = 1; foreach($settings['feature_tab'] as $key => $item): ?>
                            <a class="<?php if($count == 1) echo 'active show' ?>" data-bs-toggle="tab" href="#liton_tab_3_<?php echo esc_attr($count); ?>"><?php echo wp_kses($item['btn_title'], true); ?></a>
                            <?php $count++; endforeach; ?>
                        </div>
                    </div>
                    <div class="tab-content">
                       <?php $count = 1; foreach($settings['feature_tab'] as $keys => $item):
								
							$paged = vicodin_set($_POST, 'paged') ? esc_attr($_POST['paged']) : 1;
							
							$this->add_render_attribute( 'wrapper', 'class', 'themexriver-vicodin' );
							$args = array(
								'post_type'      => 'product',
								'posts_per_page' => vicodin_set( $item, 'query_number' ),
								'orderby'        => vicodin_set( $item, 'query_orderby' ),
								'order'          => vicodin_set( $item, 'query_order' ),
								'text_limit'     => vicodin_set( $item, 'text_limit' ),
								'paged'         => $paged
							);
				
							if( vicodin_set( $item, 'query_category' ) ) $args['product_cat'] = vicodin_set( $item, 'query_category' );
							$query = new \WP_Query( $args );
							if ( $query->have_posts()):	
						?>
                        <div class="tab-pane fade <?php if($count == 1) echo 'active show' ?>" id="liton_tab_3_<?php echo esc_attr($count); ?>">
                            <div class="ltn__product-tab-content-inner">
                                <div class="row ltn__tab-product-slider-one-active slick-arrow-1">
                                    <!-- ltn__product-item -->
                                    <div class="col-lg-12">
                                        <?php 
											$counts = 0;
											global $post;
											while ( $query->have_posts() ) : $query->the_post(); 
											$post_thumbnail_id = get_post_thumbnail_id($post->ID);
											$post_thumbnail_url = wp_get_attachment_url( $post_thumbnail_id );
										?>
										<?php if(($counts%2) == 0 && $counts != 0):?>
                                    </div>
                                    <div class="col-lg-12">
                                        <?php endif; ?>
                                        <div class="ltn__product-item ltn__product-item-3 text-center">
                                            <div class="product-img">
                                                <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_post_thumbnail('vicodin_600x600'); ?></a>
                                                <div class="product-hover-action">
                                                    <ul>
                                                        <li>
                                                            <a href="<?php echo esc_url($post_thumbnail_url); ?>" data-rel="lightcase:myCollection">
                                                                <i class="far fa-eye"></i>
                                                            </a>
                                                        </li>
                                                        <li>
                                                            <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>">
                                                                <i class="fas fa-shopping-cart"></i>
                                                            </a>
                                                        </li>
                                                    </ul>
                                                </div>
                                            </div>
                                            <div class="product-info">
                                                <div class="product-ratting">
                                                   <?php woocommerce_template_loop_rating();?>
                                                </div>
                                                <h2 class="product-title"><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h2>
                                                <div class="product-price">
                                                    <?php woocommerce_template_loop_price();?>
                                                </div>
                                            </div>
                                        </div>
                                        <?php $counts++; endwhile; ?>
                                    </div>
                                    
                                </div>
                            </div>
                        </div>
                        <?php endif;?>
                        <?php $count++; endforeach; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- PRODUCT TAB AREA END -->
    
	<?php 
	}

}