<?php
namespace VICODINPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;
/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Our_Team extends Widget_Base {
	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'vicodin_our_team';
	}
	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Our Team', 'vicodin' );
	}
	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-library-open';
	}
	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'vicodin' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'our_team',
			[
				'label' => esc_html__( 'Our Team', 'vicodin' ),
			]
		);
		$this->add_control(
				'style_two',
				[
					'label'   => esc_html__( 'Choose Different Style', 'vicodin' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'one',
					'options' => array(
						'one' => esc_html__( 'Choose  Style V1', 'vicodin' ),
						'two' => esc_html__( 'Choose  Style V2 ', 'vicodin' ),
					),
				]
			);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'vicodin' ),
			]
		);
		$this->add_control(
			'query_number',
			[
				'label'   => esc_html__( 'Number of post', 'vicodin' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 4,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_orderby',
			[
				'label'   => esc_html__( 'Order By', 'vicodin' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => array(
					'date'       => esc_html__( 'Date', 'vicodin' ),
					'title'      => esc_html__( 'Title', 'vicodin' ),
					'menu_order' => esc_html__( 'Menu Order', 'vicodin' ),
					'rand'       => esc_html__( 'Random', 'vicodin' ),
				),
			]
		);
		$this->add_control(
			'query_order',
			[
				'label'   => esc_html__( 'Order', 'vicodin' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => array(
					'DESC' => esc_html__( 'DESC', 'vicodin' ),
					'ASC'  => esc_html__( 'ASC', 'vicodin' ),
				),
			]
		);
		$this->add_control(
            'query_category', 
				[
				  'type' => Controls_Manager::SELECT,
				  'label' => esc_html__('Category', 'vicodin'),
				  'label_block' => true,
				  'options' => get_team_categories()
				]
		);
		$this->end_controls_section();
	}
	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
		
        $paged = get_query_var('paged');
		$paged = vicodin_set($_REQUEST, 'paged') ? esc_attr($_REQUEST['paged']) : $paged;
		
		$this->add_render_attribute( 'wrapper', 'class', 'themexriver-vicodin' );
		$args = array(
			'post_type'      =>  'team',
			'posts_per_page' => vicodin_set( $settings, 'query_number' ),
			'orderby'        => vicodin_set( $settings, 'query_orderby' ),
			'order'          => vicodin_set( $settings, 'query_order' ),
			'paged'         => $paged
		);
		
		if( vicodin_set( $settings, 'query_category' ) ) $args['team_cat'] = vicodin_set( $settings, 'query_category' );
		$query = new \WP_Query( $args );
		if ( $query->have_posts() ) 
		{ ?>
        
        
         <!-- TEAM AREA START (Team - 3) -->
    <div class="ltn__team-area  pb-90 <?php if($settings['style_two'] == 'two') echo 'pt-110---'; else echo 'pt-115'; ?> ">
        <div class="container">
           <?php if($settings['title']) { ?>
            <div class="row">
                <div class="col-lg-12">
                    <div class="section-title-area ltn__section-title-2--- text-center">
                        <h1 class="section-title"><?php echo wp_kses($settings['title'], true);?></h1>
                    </div>
                </div>
            </div>
            <?php } ?>  
            <div class="row justify-content-center">
                 <?php 
					while ( $query->have_posts() ) : $query->the_post(); 
				?>
                <div class="col-lg-4 col-sm-6">
                    <div class="ltn__team-item ltn__team-item-3---">
                        <div class="team-img">
                            <?php the_post_thumbnail('vicodin_600x600'); ?>
                        </div>
                        <div class="team-info">
                            <h4><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h4>
                            <h6 class="ltn__secondary-color"><?php echo (get_post_meta( get_the_id(), 'designation', true ));?></h6>
                            <div class="ltn__social-media">
								<?php
                                    $icons = get_post_meta( get_the_id(), 'social_profile', true );
                                    if ( ! empty( $icons ) ) :
                                ?>
                                 <ul>
                                    <?php
                                    foreach ( $icons as $h_icon ) :
                                    $header_social_icons = json_decode( urldecode( vicodin_set( $h_icon, 'data' ) ) );
                                    if ( vicodin_set( $header_social_icons, 'enable' ) == '' ) {
                                        continue;
                                    }
                                    $icon_class = explode( '-', vicodin_set( $header_social_icons, 'icon' ) );
                                    ?>
                                            <li><a href="<?php echo esc_url(vicodin_set( $header_social_icons, 'url' )); ?>" <?php if( vicodin_set( $header_social_icons, 'background' ) || vicodin_set( $header_social_icons, 'color' ) ):?>style="background-color:<?php echo esc_attr(vicodin_set( $header_social_icons, 'background' )); ?>; color: <?php echo esc_attr(vicodin_set( $header_social_icons, 'color' )); ?>"<?php endif;?>><i class="fab <?php echo esc_attr( vicodin_set( $header_social_icons, 'icon' ) ); ?>"></i></a></li>
                                    <?php endforeach; ?>
                                 </ul>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
                <?php endwhile; ?>
            </div>
        </div>
    </div>
    <!-- TEAM AREA END -->

         
		<?php }
		wp_reset_postdata();
	}
}