<?php namespace VICODINPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Service_Detail extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'vicodin_service_detail';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Service Detail', 'vicodin' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-library-open';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'vicodin' ];
    }

    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'service_detail',
            [
                'label' => esc_html__( 'Service Detail', 'vicodin' ),
            ]
        );
		$this->add_control(
			'sidebar_slug',
			[
				'label'   => esc_html__( 'Choose Sidebar', 'vicodin' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'Choose Sidebar',
				'options'  => vicodin_get_sidebars(),
			]
		);
		$this->add_control(
			'feature_img',
			[
				'label' => __( 'Feature Image', 'vicodin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Text', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Text', 'vicodin' ),
			]
		);
		$this->add_control(
			'feature_img_1',
			[
				'label' => __( 'Feature Image 1', 'vicodin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'feature_img_2',
			[
				'label' => __( 'Feature Image 2', 'vicodin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'text_1',
			[
				'label'       => __( 'Text 1', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Text 1', 'vicodin' ),
			]
		);
		$this->end_controls_section();
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
        ?>
		
        <!-- PAGE DETAILS AREA START (service-details) -->
    <div class="ltn__page-details-area ltn__service-details-area mb-105">
        <div class="container">
            <div class="row">
                <div class="<?php if ( is_active_sidebar( $settings['sidebar_slug'] ) ) echo 'col-lg-8 '; else echo 'col-xl-12 col-lg-12'; ?>">
                    <div class="ltn__page-details-inner ltn__service-details-inner">
                        <?php if($settings['feature_img']['id']){ ?>
                        <div class="ltn__blog-img">
                            <img src="<?php echo esc_url(wp_get_attachment_url($settings['feature_img']['id']));?>" alt="<?php esc_attr_e('Awesome Image', 'vicodin'); ?>">
                        </div>
                        <?php } ?>
                        <?php if($settings['text']){ ?>
							<?php echo wp_kses($settings['text'], true);?>
                        <?php } ?>
                        <div class="row">
                            <?php if($settings['feature_img_1']['id']){ ?>
                            <div class="col-lg-6">
                                <img src="<?php echo esc_url(wp_get_attachment_url($settings['feature_img_1']['id']));?>" alt="<?php esc_attr_e('Awesome Image', 'vicodin'); ?>">
                            </div>
                            <?php } ?>
                            <?php if($settings['feature_img_2']['id']){ ?>
                            <div class="col-lg-6">
                                <img src="<?php echo esc_url(wp_get_attachment_url($settings['feature_img_2']['id']));?>" alt="<?php esc_attr_e('Awesome Image', 'vicodin'); ?>">
                            </div>
                            <?php } ?>
                        </div>
                        <?php if($settings['text_1']){ ?>
							<?php echo wp_kses($settings['text_1'], true);?>
                        <?php } ?>
                    </div>
                </div>
                <?php if ( is_active_sidebar( $settings['sidebar_slug'] ) ) { ?>
                <div class="col-lg-4">
                    <aside class="sidebar-area ltn__right-sidebar">
                        <?php dynamic_sidebar( $settings['sidebar_slug'] ); ?>
                    </aside>
                </div>
                <?php } ?>
            </div>
        </div>
    </div>
    <!-- PAGE DETAILS AREA END -->
     
        
        
        <?php
    }
}
