<?php namespace VICODINPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Shipping_Area extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'vicodin_shipping_area';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Shipping Area', 'vicodin' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-library-open';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'vicodin' ];
    }

    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'shipping_area',
            [
                'label' => esc_html__( 'Shipping Area', 'vicodin' ),
            ]
        );
		$this->add_control(
				'style_two',
				[
					'label'   => esc_html__( 'Choose Different BG Style', 'vicodin' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'one',
					'options' => array(
						'one' => esc_html__( 'Choose Style V1', 'vicodin' ),
						'two' => esc_html__( 'Choose Style V2 ', 'vicodin' ),
						'three' => esc_html__( 'Choose Style V3', 'vicodin' ),
					),
				]
			);
		$this->add_control(
           'features', 
			  	[
            		'type' => Controls_Manager::REPEATER,
            		'separator' => 'before',
            		'default' => 
						[
                			['block_title' => esc_html__('Free shipping', 'vicodin')],
                			['block_title' => esc_html__('15 days returns', 'vicodin')],
                			['block_title' => esc_html__('Secure checkout', 'vicodin')],
                			['block_title' => esc_html__('Offer & gift here', 'vicodin')],
            			],
            		'fields' => 
						[
                			[
								'name' => 'feature_image',
								'label' => esc_html__('Feature Image', 'vicodin'),
								'type' => Controls_Manager::MEDIA,
								'default' => ['url' => Utils::get_placeholder_image_src(),],
							],
							[
                    			'name' => 'block_title',
                    			'label' => esc_html__('Title', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'block_text',
                    			'label' => esc_html__('Text', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
						],
            	    'title_field' => '{{block_title}}',
                 ]
        );
		$this->end_controls_section();
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
        ?>
		
       
   <!-- FEATURE AREA START ( Feature - 3) -->
    <div class="<?php if($settings['style_two'] == 'three') echo 'ltn__feature-area mt-35 mt--65---'; elseif($settings['style_two'] == 'two') echo 'ltn__feature-area section-bg-1 mt-90--- pt-30 pb-30 mt--65---'; else echo 'ltn__feature-area section-bg-1 mt-90 pt-30 pb-30 mt--65---'; ?>">
        <div class="container">
            <div class="row">
                <div class="col-lg-12">
                    <div class="ltn__feature-item-box-wrap <?php if($settings['style_two'] == 'three') echo 'ltn__feature-item-box-wrap-2 ltn__border section-bg-1'; elseif($settings['style_two'] == 'two') echo 'ltn__feature-item-box-wrap-2 ltn__border--- section-bg-1'; else echo 'ltn__feature-item-box-wrap-2 ltn__border--- section-bg-1'; ?>">
                       	<?php foreach($settings['features'] as $key => $item): ?>
                        <div class="ltn__feature-item ltn__feature-item-8">
                            <div class="ltn__feature-icon">
                                <img src="<?php echo esc_url(wp_get_attachment_url($item['feature_image']['id']));?>" alt="<?php esc_attr_e('Awesome Image', 'vicodin'); ?>">
                            </div>
                            <div class="ltn__feature-info">
                                <h4><?php echo wp_kses($item['block_title'], true);?></h4>
                                <p><?php echo wp_kses($item['block_text'], true);?></p>
                            </div>
                        </div>
                       <?php endforeach; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- FEATURE AREA END -->
   
   
       
       
       
             
        <?php
    }
}
