<?php namespace VICODINPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Slider_V1 extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'vicodin_slider_v1';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Slider V1', 'vicodin' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-library-open';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'vicodin' ];
    }

    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'slider_v1',
            [
                'label' => esc_html__( 'Slider V1', 'vicodin' ),
            ]
        );
		$this->add_control(
              'slides', 
			  	[
            		'type' => Controls_Manager::REPEATER,
            		'separator' => 'before',
            		'default' => 
						[
                			['title' => esc_html__('Get 20% Discount <br>Of N95 Mask', 'vicodin')],
                			['title' => esc_html__('Get 20% Discount <br>Of N95 Mask', 'vicodin')],
							['title' => esc_html__('Get 20% Discount <br>Of N95 Mask', 'vicodin')],
            			],
            		'fields' => 
						[
							[
								'name' => 'style_two',
								'label'   => esc_html__( 'Choose Different Text Style', 'vicodin' ),
								'label_block' => true,
								'type'    => Controls_Manager::SELECT,
								'default' => 'one',
								'options' => array(
									'one' => esc_html__( 'Choose Text Style Left', 'vicodin' ),
									'two' => esc_html__( 'Choose Text Style Center', 'vicodin' ),
									'three' => esc_html__( 'Choose Text Style Right ', 'vicodin' ),
								),
							],
							[
								'name' => 'bg_image',
								'label' => esc_html__('Slide BG Image', 'vicodin'),
								'type' => Controls_Manager::MEDIA,
								'default' => ['url' => Utils::get_placeholder_image_src(),],
							],
							[
                    			'name' => 'sub_title',
                    			'label' => esc_html__('Sub Title', 'vicodin'),
								'label_block' => true,
                    			'type' => Controls_Manager::TEXT,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'title',
                    			'label' => esc_html__('Title', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'text',
                    			'label' => esc_html__('Text', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'btn_title',
                    			'label' => esc_html__('Button Title', 'vicodin'),
								'label_block' => true,
                    			'type' => Controls_Manager::TEXT,
                    			'default' => esc_html__('Read More', 'vicodin')
                			],
							[
                    			'name' => 'btn_link',
								'label' => __( 'Button Link', 'vicodin' ),
							    'type' => Controls_Manager::URL,
							    'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
							    'show_external' => true,
							    'default' => ['url' => '','is_external' => true,'nofollow' => true,],
                			],
						],
            	    'title_field' => '{{title}}',
                 ]
        );
		$this->end_controls_section();
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
        ?>
		
        
         <!-- SLIDER AREA START (slider-3) -->
    <div class="ltn__slider-area ltn__slider-3  section-bg-1">
        <div class="ltn__slide-one-active slick-slide-arrow-1 slick-slide-dots-1">
            <?php foreach($settings['slides'] as $key => $item): ?>
            <!-- ltn__slide-item -->
            <div class="ltn__slide-item ltn__slide-item-2  ltn__slide-item-3-normal--- ltn__slide-item-3 bg-image bg-overlay-theme-black-60---" <?php if($item['bg_image']['id']){ ?> data-bs-bg="<?php echo esc_url(wp_get_attachment_url($item['bg_image']['id'])); ?>"<?php } ?>>
                <div class="ltn__slide-item-inner  <?php if($item['style_two'] == 'three') echo 'text-right text-end'; elseif($item['style_two'] == 'two') echo 'text-center'; else echo 'text-left'; ?>">
                    <div class="container">
                        <div class="row">
                            <div class="col-lg-12 align-self-center">
                                <div class="slide-item-info">
                                    <div class="slide-item-info-inner ltn__slide-animation">
                                        <?php if($item['sub_title']){ ?><h6 class="slide-sub-title white-color--- animated"><span><i class="fas fa-syringe"></i></span> <?php echo wp_kses($item['sub_title'], true); ?></h6>  <?php } ?>
                                        <?php if($item['title']){ ?><h1 class="slide-title animated "><?php echo wp_kses($item['title'], true); ?></h1>  <?php } ?>
                                        <?php if($item['text']){ ?>
                                        <div class="slide-brief animated">
                                            <p><?php echo wp_kses($item['text'], true); ?></p>
                                        </div>
                                          <?php } ?>
                                        <?php if($item['btn_link']['url'] and $item['btn_title']){ ?>
                                        <div class="btn-wrapper animated">
                                            <a href="<?php echo esc_url($item['btn_link']['url']); ?>" class="theme-btn-1 btn btn-effect-1"><?php echo wp_kses($item['btn_title'], true); ?></a>
                                        </div>
                                        <?php } ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
           <?php endforeach; ?>
        </div>
    </div>
    <!-- SLIDER AREA END -->
        
    

        
        <?php
    }
}
