<?php namespace VICODINPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Slider_V2 extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'vicodin_slider_v2';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Slider V2', 'vicodin' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-library-open';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'vicodin' ];
    }

    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'slider_v2',
            [
                'label' => esc_html__( 'Slider V2', 'vicodin' ),
            ]
        );
		$this->add_control(
              'slides', 
			  	[
            		'type' => Controls_Manager::REPEATER,
            		'separator' => 'before',
            		'default' => 
						[
                			['title' => esc_html__('Get 20% Discount <br>Of N95 Mask', 'vicodin')],
                			['title' => esc_html__('Get 20% Discount <br>Of N95 Mask', 'vicodin')],
							['title' => esc_html__('Get 20% Discount <br>Of N95 Mask', 'vicodin')],
            			],
            		'fields' => 
						[
							[
								'name' => 'bg_image',
								'label' => esc_html__('Slide BG Image', 'vicodin'),
								'type' => Controls_Manager::MEDIA,
								'default' => ['url' => Utils::get_placeholder_image_src(),],
							],
							[
                    			'name' => 'sub_title',
                    			'label' => esc_html__('Sub Title', 'vicodin'),
								'label_block' => true,
                    			'type' => Controls_Manager::TEXT,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'title',
                    			'label' => esc_html__('Title', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'pricing',
                    			'label' => esc_html__('Pricing', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'btn_title',
                    			'label' => esc_html__('Button Title', 'vicodin'),
								'label_block' => true,
                    			'type' => Controls_Manager::TEXT,
                    			'default' => esc_html__('Read More', 'vicodin')
                			],
							[
                    			'name' => 'btn_link',
								'label' => __( 'Button Link', 'vicodin' ),
							    'type' => Controls_Manager::URL,
							    'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
							    'show_external' => true,
							    'default' => ['url' => '','is_external' => true,'nofollow' => true,],
                			],
						],
            	    'title_field' => '{{title}}',
                 ]
        );
		
		$this->add_control(
			'bg_image2',
			[
			  'label' => __( 'BG Image', 'vicodin' ),
			  'type' => Controls_Manager::MEDIA,
			  'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
	    );
		$this->add_control(
			'image2',
			[
			  'label' => __( 'Feature Image', 'vicodin' ),
			  'type' => Controls_Manager::MEDIA,
			  'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
	    );
		$this->add_control(
			'title2',
			[
				'label'       => __( 'Title', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA, 
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title Here', 'aelpa' ),
			]
		);
		$this->add_control(
			'price2',
			[
				'label'       => __( 'Price', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA, 
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Price Here', 'vicodin' ),
			]
		);
		$this->add_control(
			'button_title2',
			[
				'label'       => __( 'Button Title', 'vicodin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT, 
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title Here', 'vicodin' ),
			]
		);
		$this->add_control(
			'button_link2',
			[
			  'label' => __( 'Button Link', 'vicodin' ),
			  'type' => Controls_Manager::URL,
			  'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
			  'show_external' => true,
			  'default' => [
				'url' => '',
					'is_external' => true,
					'nofollow' => true,
				 ],
			 ]
		);
		
		$this->add_control(
			'image3',
			[
			  'label' => __( 'Feature Image V2', 'vicodin' ),
			  'type' => Controls_Manager::MEDIA,
			  'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
	    );
		$this->add_control(
			'title3',
			[
				'label'       => __( 'Title', 'vicodin' ),
				'type'        => Controls_Manager::TEXTAREA, 
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title Here', 'vicodin' ),
			]
		);
		$this->add_control(
			'price3',
			[
				'label'       => __( 'Price', 'vicodin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXTAREA, 
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Price Here', 'vicodin' ),
			]
		);
		$this->add_control(
			'button_title3',
			[
				'label'       => __( 'Button Title', 'vicodin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT, 
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title Here', 'vicodin' ),
			]
		);
		$this->add_control(
			'button_link3',
			[
			  'label' => __( 'Button Link', 'vicodin' ),
			  'type' => Controls_Manager::URL,
			  'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
			  'show_external' => true,
			  'default' => [
				'url' => '',
					'is_external' => true,
					'nofollow' => true,
				 ],
			 ]
		);
		
		$this->end_controls_section();
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
    ?>
	   
    <!-- SLIDER AREA START (slider-3) -->
    <div class="ltn__slider-area ltn__slider-3---  section-bg-1--- mt-30">
        <div class="container">
            <div class="row">
                <div class="col-lg-7">
                    <div class="ltn__slide-active-2 slick-slide-arrow-1 slick-slide-dots-1 mb-30">
                        <?php foreach($settings['slides'] as $key => $item): ?>
                        <!-- ltn__slide-item -->
                        <div class="ltn__slide-item ltn__slide-item-10 section-bg-1 bg-image" <?php if($item['bg_image']['id']){ ?> data-bs-bg="<?php echo esc_url(wp_get_attachment_url($item['bg_image']['id'])); ?>"<?php } ?>>
                            <div class="ltn__slide-item-inner">
                                <div class="container">
                                    <div class="row">
                                        <div class="col-lg-7 col-md-7 col-sm-7 align-self-center">
                                            <div class="slide-item-info">
                                                <div class="slide-item-info-inner ltn__slide-animation">
                                                     <?php if($item['sub_title']){ ?><h6 class="slide-sub-title ltn__secondary-color animated"><?php echo wp_kses($item['sub_title'], true); ?></h6><?php } ?>
                                                     <?php if($item['title']){ ?><h1 class="slide-title  animated"><?php echo wp_kses($item['title'], true); ?></h1><?php } ?>
                                                    <?php if($item['pricing']){ ?><h5 class="color-orange  animated"><?php echo wp_kses($item['pricing'], true); ?></h5><?php } ?>
                                                    <?php if($item['btn_link']['url'] and $item['btn_title']){ ?>
                                                    <div class="btn-wrapper  animated">
                                                        <a href="<?php echo esc_url($item['btn_link']['url']); ?>" class="theme-btn-1 btn btn-effect-1"><?php echo wp_kses($item['btn_title'], true); ?></a>
                                                    </div>
                                                    <?php } ?>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="col-lg-5 col-md-5 col-sm-5 align-self-center">
                                            <div class="slide-item-img">
                                                <!-- <a href="shop.html"><img src="img/product/1.png" alt="Image"></a> -->
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                         <?php endforeach; ?>
                    </div>
                </div>
                <div class="col-lg-5">
                    <!-- Kit Block -->
                    <div class="kit-block">
						<div class="inner-box" <?php if($settings['bg_image2']['id']){ ?>style="background-image: url(<?php echo esc_url(wp_get_attachment_url($settings['bg_image2']['id'])); ?>)"<?php } ?>>
							<div class="content">
								<h3><a href="<?php echo esc_url($settings['button_link2']['url']); ?>"><?php echo wp_kses( $settings['title2'], true );?></a></h3>
								<div class="price"><?php echo wp_kses( $settings['price2'], true );?> </div>
								<?php if($settings['button_link2']['url']){ ?>
                                <a class="shop" href="<?php echo esc_url($settings['button_link2']['url']); ?>"><?php echo wp_kses($settings['button_title2'], true); ?> <span class="fas fa-arrow-right fa-fw"></span></a>
                                <?php } ?>
							</div>
							<?php if($settings['image2']['id']){ ?>
                            <div class="image">
                                <img src="<?php echo esc_url(wp_get_attachment_url($settings['image2']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'broccoli'); ?>">
                            </div>
                            <?php } ?>
						</div>
                    </div>
                    
					<!-- Kit Block Two -->
                    <div class="kit-block-two">
						<div class="inner-box">
							<div class="row clearfix">
								<?php if($settings['image3']['id']){ ?>
                                <div class="image-column col-lg-6 col-md-6 col-sm-12">
									<div class="image">
										<img src="<?php echo esc_url(wp_get_attachment_url($settings['image3']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'broccoli'); ?>">
									</div>
								</div>
                                <?php } ?>
								<div class="content col-lg-6 col-md-6 col-sm-12">
									<h3><a href="<?php echo esc_url($settings['button_link3']['url']); ?>"><?php echo wp_kses( $settings['title3'], true );?></a></h3>
									<div class="price"><?php echo wp_kses( $settings['price3'], true );?> </div>
									<?php if($settings['button_link3']['url']){ ?>
                                    <a class="shop" href="<?php echo esc_url($settings['button_link3']['url']); ?>"><?php echo wp_kses($settings['button_title3'], true); ?> <span class="fas fa-arrow-right fa-fw"></span></a>
                                    <?php } ?>
								</div>
							</div>
						</div>
					</div>
					
                </div>
            </div>
        </div>
    </div>
    <!-- SLIDER AREA END --> 
         
    <?php
    }
}
