<?php namespace VICODINPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Slider_V3 extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'vicodin_slider_v3';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Slider V3', 'vicodin' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-library-open';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'vicodin' ];
    }

    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'slider_v3',
            [
                'label' => esc_html__( 'Slider V3', 'vicodin' ),
            ]
        );
		$this->add_control(
			'show_categories',
			[
				'label'       => __( 'Enable/Disable Categories List', 'vicodin' ),
                'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'vicodin' ),
				'label_off' => __( 'Hide', 'vicodin' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$this->add_control(
              'category_list', 
			  	[
            		'type' => Controls_Manager::REPEATER,
            		'separator' => 'before',
					'condition' => [
						'show_categories' => 'yes',
					],
            		'default' => 
						[
                			['categories_list_title' => esc_html__('Health Care', 'vicodin')],
                			['categories_list_title' => esc_html__('First Aid', 'vicodin')],
							['categories_list_title' => esc_html__('Surgical Product', 'vicodin')],
							['categories_list_title' => esc_html__('Diagnostic Product', 'vicodin')],
							['categories_list_title' => esc_html__('Laboratory Product', 'vicodin')],
							['categories_list_title' => esc_html__('Hospital Products', 'vicodin')],
							['categories_list_title' => esc_html__('Service & Setup', 'vicodin')],
							['categories_list_title' => esc_html__('Food & Nutrition', 'vicodin')],
							['categories_list_title' => esc_html__('Apple Juice', 'vicodin')]
            			],
            		'fields' => 
						[
							[
                    			'name' => 'categories_list_icon',
                    			'label' => esc_html__('Enter The icons', 'vicodin'),
								'label_block' => true,
                    			'type' => Controls_Manager::SELECT2,
                    			'options'  => get_fontawesome_icons(),
                			],
							[
                    			'name' => 'categories_list_title',
                    			'label' => esc_html__('Category List Title', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'categories_list_link',
								'label' => __( 'External Link', 'vicodin' ),
							    'type' => Controls_Manager::URL,
							    'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
							    'show_external' => true,
							    'default' => ['url' => '','is_external' => true,'nofollow' => true,],
                			],
						],
            	    'title_field' => '{{categories_list_title}}',
                 ]
        );
		$this->add_control(
              'slides', 
			  	[
            		'type' => Controls_Manager::REPEATER,
            		'separator' => 'before',
            		'default' => 
						[
                			['title' => esc_html__('Get 20% Discount <br>Of N95 Mask', 'vicodin')],
                			['title' => esc_html__('Get 20% Discount <br>Of N95 Mask', 'vicodin')],
							['title' => esc_html__('Get 20% Discount <br>Of N95 Mask', 'vicodin')],
            			],
            		'fields' => 
						[
							[
								'name' => 'bg_image',
								'label' => esc_html__('Slide BG Image', 'vicodin'),
								'type' => Controls_Manager::MEDIA,
								'default' => ['url' => Utils::get_placeholder_image_src(),],
							],
							[
                    			'name' => 'sub_title',
                    			'label' => esc_html__('Sub Title', 'vicodin'),
								'label_block' => true,
                    			'type' => Controls_Manager::TEXT,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'title',
                    			'label' => esc_html__('Title', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'pricing',
                    			'label' => esc_html__('Pricing', 'vicodin'),
                    			'type' => Controls_Manager::TEXTAREA,
                    			'default' => esc_html__('', 'vicodin')
                			],
							[
                    			'name' => 'btn_title',
                    			'label' => esc_html__('Button Title', 'vicodin'),
								'label_block' => true,
                    			'type' => Controls_Manager::TEXT,
                    			'default' => esc_html__('Read More', 'vicodin')
                			],
							[
                    			'name' => 'btn_link',
								'label' => __( 'Button Link', 'vicodin' ),
							    'type' => Controls_Manager::URL,
							    'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
							    'show_external' => true,
							    'default' => ['url' => '','is_external' => true,'nofollow' => true,],
                			],
						],
            	    'title_field' => '{{title}}',
                 ]
        );
		$this->end_controls_section();
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
    ?>        
       
	 <!-- SLIDER AREA START (slider-3) -->
     <div class="ltn__slider-area ltn__slider-3---  section-bg-1--- mt-30">
        <div class="container">
            <div class="row">
                <?php if($settings['show_categories']){ ?>
                <div class="col-lg-3">
                    <!-- CATEGORY-MENU-LIST START -->
                    <div class="ltn__category-menu-wrap">
                        <div class="ltn__category-menu-title">
                            <h2 class="section-bg-1 ltn__secondary-bg text-color-white"><?php esc_html_e('categories', 'vicodin'); ?></h2>
                        </div>
                        <div class="ltn__category-menu-toggle ltn__one-line-active">
                            <ul>
                                <?php foreach($settings['category_list'] as $key => $item): ?>
                                <li class="ltn__category-menu-item ltn__category-menu-drop"><a href="<?php echo esc_url($item['categories_list_link']['url']); ?>"><i class="<?php echo wp_kses(str_replace( "icon ",  "",  $item['categories_list_icon']), true); ?>"></i><?php echo wp_kses($item['categories_list_title'], true); ?> </a></li>
                            	<?php endforeach; ?>
                            </ul>
                        </div>
                    </div>
                    <!-- END CATEGORY-MENU-LIST -->
                </div>
                <?php } ?>
                <div class="<?php if ( $settings['show_categories'] ) echo 'col-lg-9'; else echo 'col-xl-12 col-lg-12'; ?>">
                    <div class="ltn__slide-active-2 slick-slide-arrow-1 slick-slide-dots-1">
                        <?php foreach($settings['slides'] as $key => $item): ?>
                        <!-- ltn__slide-item -->
                        <div class="ltn__slide-item ltn__slide-item-10 section-bg-1 bg-image" <?php if($item['bg_image']['id']){ ?> data-bs-bg="<?php echo esc_url(wp_get_attachment_url($item['bg_image']['id'])); ?>"<?php } ?>>
                            <div class="ltn__slide-item-inner">
                                <div class="container">
                                    <div class="row">
                                        <div class="col-lg-7 col-md-7 col-sm-7 align-self-center">
                                            <div class="slide-item-info">
                                                <div class="slide-item-info-inner ltn__slide-animation">
                                                    <?php if($item['sub_title']){ ?><h5 class="slide-sub-title ltn__secondary-color animated text-uppercase"><?php echo wp_kses($item['sub_title'], true); ?></h5><?php } ?>
                                                    <?php if($item['title']){ ?><h1 class="slide-title  animated"><?php echo wp_kses($item['title'], true); ?></h1><?php } ?>
                                                    <?php if($item['pricing']){ ?><h5 class="color-orange  animated"><?php echo wp_kses($item['pricing'], true); ?></h5><?php } ?>
                                                    <?php if($item['btn_link']['url'] and $item['btn_title']){ ?>
                                                    <div class="btn-wrapper  animated">
                                                        <a href="<?php echo esc_url($item['btn_link']['url']); ?>" class="theme-btn-1 btn btn-effect-1 text-uppercase"><?php echo wp_kses($item['btn_title'], true); ?></a>
                                                    </div>
                                                    <?php } ?>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="col-lg-5 col-md-5 col-sm-5 align-self-center">
                                            <div class="slide-item-img">
                                                <!-- <a href="shop.html"><img src="img/product/1.png" alt="Image"></a> -->
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- SLIDER AREA END -->
	
	<?php
    }
}
