<?php

namespace VICODINPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Trending_Products extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'vicodin_trending_products';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Trending Products', 'vicodin' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-library-open';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'vicodin' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'trending_products',
			[
				'label' => esc_html__( 'Trending Products', 'vicodin' ),
			]
		);
		$this->add_control(
				'style_two',
				[
					'label'   => esc_html__( 'Choose Different Style', 'vicodin' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'one',
					'options' => array(
						'one' => esc_html__( 'Choose Style Without Carousel ', 'vicodin' ),
						'two' => esc_html__( 'Choose Style With Carousel ', 'vicodin' ),
					),
				]
			);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'vicodin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'vicodin' ),
			]
		);
		$this->add_control(
			'query_number',
			[
				'label'   => esc_html__( 'Number of post', 'vicodin' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 3,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_orderby',
			[
				'label'   => esc_html__( 'Order By', 'vicodin' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => array(
					'date'       => esc_html__( 'Date', 'vicodin' ),
					'title'      => esc_html__( 'Title', 'vicodin' ),
					'menu_order' => esc_html__( 'Menu Order', 'vicodin' ),
					'rand'       => esc_html__( 'Random', 'vicodin' ),
				),
			]
		);
		$this->add_control(
			'query_order',
			[
				'label'   => esc_html__( 'Order', 'vicodin' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => array(
					'DESC' => esc_html__( 'DESC', 'vicodin' ),
					'ASC'  => esc_html__( 'ASC', 'vicodin' ),
				),
			]
		);
		$this->add_control(
            'query_category', 
			[
			  'type' => Controls_Manager::SELECT,
			  'label' => esc_html__('Category', 'vicodin'),
			  'options' => get_product_categories(),
			  'label_block' => true,
			]
		);
		$this->end_controls_section();
	}
	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
		
        $paged = get_query_var('paged');
		$paged = vicodin_set($_REQUEST, 'paged') ? esc_attr($_REQUEST['paged']) : $paged;

		$this->add_render_attribute( 'wrapper', 'class', 'themexriver-vicodin' );
		$args = array(
			'post_type'      => 'product',
			'posts_per_page' => vicodin_set( $settings, 'query_number' ),
			'orderby'        => vicodin_set( $settings, 'query_orderby' ),
			'order'          => vicodin_set( $settings, 'query_order' ),
			'paged'         => $paged
		);
		
		if( vicodin_set( $settings, 'query_category' ) ) $args['product_cat'] = vicodin_set( $settings, 'query_category' );
		$query = new \WP_Query( $args );

		if ( $query->have_posts() ) 
		{ ?>
	
    <?php if($settings['style_two'] == 'two'): ?>
    
    	
   <!-- PRODUCT AREA START (product-item-3) -->
    <div class="woocommerce ltn__product-area ltn__product-gutter  no-product-ratting pt-115 pb-70---">
        <div class="container">
            <div class="row">
                <div class="col-lg-12">
                    <?php if($settings['title']){ ?>
                    <div class="section-title-area ltn__section-title-2 text-center">
                        <h1 class="section-title"><?php echo wp_kses($settings['title'], true);?></h1>
                    </div>
                    <?php } ?>
                </div>
            </div>
            <div class="row ltn__tab-product-slider-one-active slick-arrow-1">
                 <?php 
					global $post;
					while ( $query->have_posts() ) : $query->the_post(); 
					$post_thumbnail_id = get_post_thumbnail_id($post->ID);
					$post_thumbnail_url = wp_get_attachment_url( $post_thumbnail_id );
				?>
                <!-- ltn__product-item -->
                <div class="col-lg-3 col-md-4 col-sm-6 col-6">
                    <div class="ltn__product-item ltn__product-item-3 text-center">
                        <div class="product-img">
                            <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_post_thumbnail('vicodin_600x701'); ?></a>
                            <div class="product-hover-action">
                                <ul>
                                    <li>
                                        <a href="<?php echo esc_url($post_thumbnail_url); ?>" data-rel="lightcase:myCollection">
                                            <i class="far fa-eye"></i>
                                        </a>
                                    </li>
                                    <li>
                                        <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>">
                                            <i class="fas fa-shopping-cart"></i>
                                        </a>
                                    </li>
                                </ul>
                            </div>
                        </div>
                        <div class="product-info">
                            <div class="product-ratting">
                                <?php woocommerce_template_loop_rating();?>
                            </div>
                            <h2 class="product-title"><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h2>
                            <div class="product-price">
                                 <?php woocommerce_template_loop_price();?>
                            </div>
                        </div>
                    </div>
                </div>
                 <?php endwhile; ?>
            </div>
        </div>
    </div>
    <!-- PRODUCT AREA END -->

	<?php else: ?> 


    <!-- PRODUCT AREA START (product-item-3) -->
    <div class="ltn__product-area ltn__product-gutter  no-product-ratting pt-115 pb-70---">
        <div class="container">
            <div class="row">
                <div class="col-lg-12">
                    <?php if($settings['title']){ ?>
                    <div class="section-title-area ltn__section-title-2 text-center">
                        <h1 class="section-title"><?php echo wp_kses($settings['title'], true);?></h1>
                    </div>
                    <?php } ?>
                </div>
            </div>
            <div class="row ltn__tab-product-slider-one-active--- slick-arrow-1">
                <?php 
					global $post;
					while ( $query->have_posts() ) : $query->the_post(); 
					$post_thumbnail_id = get_post_thumbnail_id($post->ID);
					$post_thumbnail_url = wp_get_attachment_url( $post_thumbnail_id );
				?>
                <!-- ltn__product-item -->
                <div class="col-lg-3 col-md-4 col-sm-6 col-6">
                    <div class="ltn__product-item ltn__product-item-3 text-center">
                        <div class="product-img">
                            <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_post_thumbnail('vicodin_600x701'); ?></a>
                            <div class="product-hover-action">
                                <ul>
                                    <li>
                                        <a href="<?php echo esc_url($post_thumbnail_url); ?>" data-rel="lightcase:myCollection">
                                            <i class="far fa-eye"></i>
                                        </a>
                                    </li>
                                    <li>
                                        <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>" >
                                            <i class="fas fa-shopping-cart"></i>
                                        </a>
                                    </li>
                                </ul>
                            </div>
                        </div>
                        <div class="product-info">
                            <div class="product-ratting">
                                <?php woocommerce_template_loop_rating();?>
                            </div>
                            <h2 class="product-title"><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h2>
                            <div class="product-price">
                                 <?php woocommerce_template_loop_price();?>
                            </div>
                        </div>
                    </div>
                </div>
                 <?php endwhile; ?>
            </div>
        </div>
    </div>
    <!-- PRODUCT AREA END -->
   
   

   

   
                                        
        <?php endif; }
		wp_reset_postdata();
	}
}